/* Z80 emulator               */
/* AKIKAWA, Hisashi 2015.10.5 */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <ctype.h>
#include "z80.h"

#define BC (pcpu->c + (pcpu->b << 8))
#define DE (pcpu->e + (pcpu->d << 8))
#define HL (pcpu->l + (pcpu->h << 8))
#define IX (pcpu->ixl + (pcpu->ixh << 8))
#define IY (pcpu->iyl + (pcpu->iyh << 8))
#define IXD (word)((int32_t)IX + (int8_t)z80_read(pcpu->pc++))
#define IYD (word)((int32_t)IY + (int8_t)z80_read(pcpu->pc++))

#define FLAGS(var8)		\
  ((var8 & SF)			\
   | (var8 ? 0 : ZF)		\
   | (var8 & YF)		\
   | 0				\
   | (var8 & XF)		\
   | parity_table[var8]		\
   | 0				\
   | 0				\
   )

#define MREG(operation)		\
  do {				\
    tmp8 = z80_read(HL);	\
    operation(tmp8);		\
    z80_write(HL,tmp8);		\
  } while (0)

#define INC(var8)			\
  do {					\
    var8++;				\
    pcpu->f				\
      = ((var8 & 0x80) ? SF : 0)	\
      | (var8 ? 0: ZF)			\
      | (var8 & YF)			\
      | ((var8 & 0x0f) ? 0 : HF)	\
      | (var8 & XF)			\
      | ((var8 == 0x80) ? VF : 0)	\
      | 0				\
      | (pcpu->f & CF);			\
  } while (0)

#define DEC(var8)				\
  do {						\
    var8--;					\
    pcpu->f					\
      = ((var8 & 0x80) ? SF : 0)		\
      | (var8 ? 0: ZF)				\
      | (var8 & YF)				\
      | (((var8 & 0x0f) == 0x0f) ? HF : 0)	\
      | (var8 & XF)				\
      | ((var8 == 0x7f) ? VF : 0)		\
      | NF					\
      | (pcpu->f & CF);				\
  } while (0)

#define INCW(high, low)		\
  do {				\
    if (++pcpu->low == 0) {	\
      pcpu->high++;		\
    }				\
  } while (0)

#define DECW(high, low)		\
  do {				\
    if (pcpu->low-- == 0) {	\
      pcpu->high--;		\
    }				\
  } while (0)

#define ADD(val)						\
  do {								\
    tmp8 = val;							\
    tmp16 = pcpu->a + tmp8;					\
    pcpu->f							\
      = ((tmp16 & 0x80) ? SF : 0)				\
      | ((tmp16 & 0xff) ? 0 : ZF)				\
      | (tmp16 & YF)						\
      | ((pcpu->a ^ tmp8 ^ tmp16) & HF)				\
      | (tmp16 & XF)						\
      | (((pcpu->a ^ tmp16) & (tmp8 ^ tmp16) & 0x80) ? VF : 0)	\
      | 0							\
      | ((tmp16 & 0x100) ? CF : 0);				\
    pcpu->a = tmp16 & 0xff;					\
  } while (0)

#define ADC(val)						\
  do {								\
    tmp8 = val;							\
    tmp16 = pcpu->a + tmp8 + (pcpu->f & CF);			\
    pcpu->f							\
      = (tmp16 & SF)						\
      | ((tmp16 & 0xff) ? 0: ZF)				\
      | (tmp16 & YF)						\
      | ((pcpu->a ^ tmp8 ^ tmp16) & HF)				\
      | (tmp16 & XF)						\
      | (((pcpu->a ^ tmp16) & (tmp8 ^ tmp16) & 0x80) ? VF : 0)	\
      | 0							\
      | ((tmp16 & 0x100) ? CF : 0);				\
    pcpu->a = tmp16 & 0xff;					\
  } while (0)

#define SUB(val)							\
  do {									\
    tmp8 = val;								\
    tmp16 = pcpu->a - tmp8;						\
    pcpu->f								\
      = (tmp16 & SF)							\
      | (tmp16 ? 0: ZF)							\
      | (tmp16 & YF)							\
      | ((pcpu->a ^ tmp8 ^ tmp16) & HF)					\
      | (tmp16 & XF)							\
      | (((pcpu->a ^ tmp8) & (pcpu->a ^ tmp16) & 0x80) ? VF : 0)	\
      | NF								\
      | ((pcpu->a < tmp8) ? CF : 0);					\
    pcpu->a = tmp16 & 0xff;						\
  } while (0)

#define SBC(val)							\
  do {									\
    tmp8 = val;								\
    tmp16 = pcpu->a - tmp8 - (pcpu->f & CF);				\
    pcpu->f								\
      = (tmp16 & SF)							\
      | ((tmp16 & 0xff) ? 0: ZF)					\
      | (tmp16 & YF)							\
      | ((pcpu->a ^ tmp8 ^ tmp16) & HF)					\
      | (tmp16 & XF)							\
      | (((pcpu->a ^ tmp8) & (pcpu->a ^ tmp16) & 0x80) ? VF : 0)	\
      | NF								\
      | ((pcpu->a < tmp8 + (pcpu->f & CF)) ? CF : 0);			\
    pcpu->a = tmp16 & 0xff;						\
  } while (0)

#define ADDW(high, low, val)					\
  do {								\
    tmp16 = val;						\
    pcpu->internal = tmp16 >> 8;				\
    tmp32 = pcpu->low + (pcpu->high << 8) + tmp16;		\
    pcpu->f							\
      = (pcpu->f & SF)						\
      | (pcpu->f & ZF)						\
      | ((tmp32 >> 8) & YF)					\
      | ((pcpu->high ^ (tmp16 >> 8) ^ (tmp32 >> 8)) & HF)	\
      | ((tmp32 >> 8) & XF)					\
      | (pcpu->f & VF)						\
      | 0							\
      | ((tmp32 & 0x10000) ? CF : 0);				\
    pcpu->high = (tmp32 >> 8) & 0xff;				\
    pcpu->low = tmp32 & 0xff;					\
  } while (0)

#define ADCHL(val)							\
  do {									\
    tmp16 = val;							\
    tmp32 = HL + tmp16 + (pcpu->f & CF);				\
    pcpu->f								\
      = ((tmp32 >> 8) & SF)						\
      | ((tmp32 & 0xffff) ? 0 : ZF)					\
      | ((tmp32 >> 8) & YF)						\
      | ((pcpu->h ^ (tmp16 >> 8) ^ (tmp32 >> 8)) & HF)			\
      | ((tmp32 >> 8) & XF)						\
      | ((((pcpu->h << 8) ^ tmp32) & (tmp16 ^ tmp32) & 0x8000) ? VF : 0)\
      | 0								\
      | ((tmp32 & 0x10000) ? CF : 0);					\
    pcpu->h = (tmp32 >> 8) & 0xff;					\
    pcpu->l = tmp32 & 0xff;						\
  } while (0)

#define SBCHL(val)							\
  do {									\
    tmp16 = val;							\
    tmp32 = HL - tmp16 - (pcpu->f & CF);				\
    pcpu->f								\
      = ((tmp32 >> 8) & SF)						\
      | ((tmp32 & 0xffff) ? 0 : ZF)					\
      | ((tmp32 >> 8) & YF)						\
      | ((pcpu->h ^ (tmp16 >> 8) ^ (tmp32 >> 8)) & HF)			\
      | ((tmp32 >> 8) & XF)						\
      | ((((pcpu->h << 8) ^ tmp16) & ((pcpu->h << 8) ^ tmp32) & 0x8000) ? VF : 0) \
      | NF								\
      | ((tmp32 > 0xffff) ? CF : 0);					\
    pcpu->h = (tmp32 >> 8) & 0xff;					\
    pcpu->l = tmp32 & 0xff;						\
  } while (0)

#define AND(val)			\
  do {					\
    pcpu->a = pcpu->a & (val);		\
    pcpu->f = FLAGS(pcpu->a) | HF;	\
  } while (0)

#define XOR(val)		\
  do {				\
    pcpu->a = pcpu->a ^ (val);	\
    pcpu->f = FLAGS(pcpu->a);	\
  } while (0)

#define OR(val)			\
  do {				\
    pcpu->a = pcpu->a | (val);	\
    pcpu->f = FLAGS(pcpu->a);	\
  } while (0)

#define CP(val)								\
  do {									\
    tmp8 = val;								\
    tmp16 = pcpu->a - tmp8;						\
    pcpu->f								\
      = (tmp16 & SF)							\
      | (tmp16 ? 0 : ZF)						\
      | (tmp8 & YF)							\
      | ((pcpu->a ^ tmp8 ^ tmp16) & HF)					\
      | (tmp8 & XF)							\
      | (((pcpu->a ^ tmp8) & (pcpu->a ^ tmp16) & 0x80) ? VF : 0)	\
      | NF								\
      | ((pcpu->a < tmp8) ? CF : 0);					\
  } while (0)

#define JPCND(flag, condition)			\
  do {						\
    tmp16 = z80_read(pcpu->pc++);		\
    tmp16 += z80_read(pcpu->pc++) << 8;		\
    if ((pcpu->f & (flag)) == (condition)) {	\
      pcpu->pc = tmp16;				\
    }						\
  } while (0)

#define JR()								\
  do {									\
    tmp8 = z80_read(pcpu->pc++);					\
    tmp16 = pcpu->pc + ((tmp8 < 0x80) ? tmp8 : (tmp8 - 0x100));		\
    pcpu->internal = tmp16 >> 8;					\
    pcpu->pc = tmp16;							\
  } while (0)

#define JRCND(flag, condition)			\
  do {						\
    if ((pcpu->f & (flag)) == (condition)) {	\
      JR();					\
    } else {					\
      z80_read(pcpu->pc++);			\
      pcpu->cycles -= 5;			\
    }						\
  } while (0)

#define CALL()					\
  do {						\
    tmp16 = z80_read(pcpu->pc++);		\
    tmp16 += (z80_read(pcpu->pc++) << 8);	\
    RST(tmp16);					\
  } while (0)

#define CALLCND(flag, condition)		\
  do {						\
    tmp16 = z80_read(pcpu->pc++);		\
    tmp16 += (z80_read(pcpu->pc++) << 8);	\
    if ((pcpu->f & (flag)) == (condition)) {	\
      RST(tmp16);				\
    } else {					\
      pcpu->cycles -= 7;			\
    }						\
  } while (0)

#define RST(address)				\
  do {						\
    z80_write(--pcpu->sp, pcpu->pc >> 8);	\
    z80_write(--pcpu->sp, pcpu->pc & 0xff);	\
    pcpu->pc = address;				\
  } while (0)

#define RET()					\
  do {						\
    pcpu->pc = z80_read(pcpu->sp++);		\
    pcpu->pc += z80_read(pcpu->sp++) << 8;	\
  } while (0)

#define RETCND(flag, condition)			\
  do {						\
    if ((pcpu->f & (flag)) == (condition)) {	\
      RET();					\
    } else {					\
      pcpu->cycles -= 6;			\
    }						\
  } while (0)

#define PUSH(high, low)			\
  do {					\
    z80_write(--pcpu->sp, pcpu->high);	\
    z80_write(--pcpu->sp, pcpu->low);	\
  } while (0)

#define POP(high, low)			\
  do {					\
    pcpu->low = z80_read(pcpu->sp++);	\
    pcpu->high = z80_read(pcpu->sp++);	\
  } while (0)

#define RLC(var8)					\
  do {							\
    var8 = (var8 << 1) + (var8 >> 7);			\
    pcpu->f = FLAGS(var8) | ((var8 & 0x01) ? CF : 0);	\
  } while (0)

#define RRC(var8)					\
  do {							\
    var8 = (var8 >> 1) + (var8 << 7);			\
    pcpu->f = FLAGS(var8) | ((var8 & 0x80) ? CF : 0);	\
  } while (0)

#define RL(var8)					\
  do {							\
    if (var8 & 0x80) {					\
      var8 = (var8 << 1) + ((pcpu->f & CF) ? 0x01 : 0);	\
      pcpu->f = FLAGS(var8) | CF;			\
    } else {						\
      var8 = (var8 << 1) + ((pcpu->f & CF) ? 0x01 : 0);	\
      pcpu->f = FLAGS(var8);				\
    }							\
  } while (0)

#define RR(var8)					\
  do {							\
    if (var8 & 0x01) {					\
      var8 = (var8 >> 1) + ((pcpu->f & CF) ? 0x80 : 0);	\
      pcpu->f = FLAGS(var8) | CF;			\
    } else {						\
      var8 = (var8 >> 1) + ((pcpu->f & CF) ? 0x80 : 0);	\
      pcpu->f = FLAGS(var8);				\
    }							\
  } while (0)

#define SLA(var8)			\
  do {					\
    pcpu->f = (var8 & 0x80) ? CF : 0;	\
    var8 = var8 << 1;			\
    pcpu->f |= FLAGS(var8);		\
  } while (0)

#define SRA(var8)			\
  do {					\
    pcpu->f = (var8 & 0x01) ? CF : 0;	\
    var8 = (var8 & 0x80) | (var8 >> 1);	\
    pcpu->f |= FLAGS(var8);		\
  } while (0)

#define SLL(var8)			\
  do {					\
    pcpu->f = (var8 & 0x80) ? CF : 0;	\
    var8 = (var8 << 1) + 0x01;		\
    pcpu->f |= FLAGS(var8);		\
  } while (0)

#define SRL(var8)			\
  do {					\
    pcpu->f = (var8 & 0x01) ? CF : 0;	\
    var8 = var8 >> 1;			\
    pcpu->f |= FLAGS(var8);		\
  } while (0)

#define BIT(n, val)			\
  do {					\
    tmp8 = val;				\
    pcpu->f				\
      = (tmp8 & (1 << (n)) & SF)	\
      | ((tmp8 & (1 << (n))) ? 0 : ZF)	\
      | (tmp8 & YF)			\
      | HF				\
      | (tmp8 & XF)			\
      | ((tmp8 & (1 << (n))) ? 0 : PF)	\
      | 0				\
      | (pcpu->f & CF);			\
  } while (0)

#define BITM(n)				\
  do {					\
    tmp8 = z80_read(HL) & (1 << (n));	\
    pcpu->f				\
      = (tmp8 & SF)			\
      | (tmp8 ? 0 : ZF)			\
      | (pcpu->internal & YF)		\
      | HF				\
      | (pcpu->internal & XF)		\
      | (tmp8 ? 0 : PF)			\
      | 0				\
      | (pcpu->f & CF);			\
  } while (0)

#define BITIXY(n, val)			\
  do {					\
    tmp8 = val;				\
    pcpu->f				\
      = (tmp8 & (1 << (n)) & SF)	\
      | ((tmp8 & (1 << (n))) ? 0 : ZF)	\
      | ((tmp16 >> 8) & YF)		\
      | HF				\
      | ((tmp16 >> 8) & XF)		\
      | ((tmp8 & (1 << (n))) ? 0 : PF)	\
      | 0				\
      | (pcpu->f & CF);			\
  } while (0)

#define RES(n, var8)		\
  do {				\
    var8 &= ~(1 << (n));	\
  } while (0)

#define RESM(n)					\
  do {						\
    z80_write(HL, z80_read(HL) & ~(1 << (n)));	\
  } while (0)

#define SET(n, var8)		\
  do {				\
    var8 |= (1 << (n));		\
  } while (0)

#define SETM(n)					\
  do {						\
    z80_write(HL, z80_read(HL) | (1 << (n)));	\
  } while (0)

#define IXY(operation, var8)			\
  do {						\
    var8 = z80_read(tmp16);			\
    operation(var8);				\
    z80_write(tmp16, var8);			\
  } while (0)

#define IXY2(operation, n, var8)		\
  do {						\
    var8 = z80_read(tmp16);			\
    operation(n, var8);				\
    z80_write(tmp16, var8);			\
  } while (0)

#define BLOCK_COPY()			\
  do {					\
    tmp8 = z80_read(HL);		\
    z80_write(DE, tmp8);		\
    tmp8 += pcpu->a;			\
    DECW(b, c);				\
    pcpu->f				\
      = (pcpu->f & SF)			\
      | (pcpu->f & ZF)			\
      | ((tmp8 & 0x02) ? YF : 0)	\
      | 0				\
      | (tmp8 & XF)			\
      | (BC ? PF : 0)			\
      | 0				\
      | (pcpu->f & CF);			\
  } while (0)

#define BLOCK_SEARCH()			\
  do {					\
    DECW(b, c);				\
    tmp8 = z80_read(HL);		\
    tmp16 = pcpu->a - tmp8;		\
    pcpu->f				\
      = (tmp16 & SF)			\
      | (tmp16 ? 0 : ZF)		\
      | (pcpu->a ^ tmp8 ^ tmp16) & HF	\
      | (BC ? PF : 0)			\
      | NF				\
      | (pcpu->f & CF);			\
    tmp16 -= ((pcpu->f & HF) ? 1 : 0);	\
    pcpu->f				\
      |= ((tmp16 & 0x02) ? YF : 0)	\
      | (tmp16 & XF);			\
  } while (0)

#define BLOCK_INPUT1()			\
  do {					\
    tmp8 =z80_in(BC);			\
    z80_write(HL, tmp8);		\
    pcpu->b--;				\
  } while (0)

#define BLOCK_INPUT2()				\
  do {						\
    pcpu->f					\
      = ((pcpu->b & 0x80) ? SF : 0)		\
      | (pcpu->b ? 0 : ZF)			\
      | (pcpu->b & YF)				\
      | ((tmp16 > 0xff) ? HF : 0)		\
      | (pcpu->b & XF)				\
      | parity_table[(tmp16 & 0x07) ^ pcpu->b]	\
      | ((tmp8 & 0x80) ? NF : 0)		\
      | ((tmp16 > 0xff) ? CF : 0);		\
  } while (0)

#define BLOCK_OUTPUT1()				\
  do {						\
    tmp8 =z80_read(HL);				\
    pcpu->b--;					\
    z80_out(BC, tmp8);				\
  } while (0)

#define BLOCK_OUTPUT2()				\
  do {						\
    tmp16 = tmp8 + pcpu->l;			\
    pcpu->f					\
      = ((pcpu->b & 0x80) ? SF : 0)		\
      | (pcpu->b ? 0 : ZF)			\
      | (pcpu->b & YF)				\
      | ((tmp16 > 0xff) ? HF : 0)		\
      | (pcpu->b & XF)				\
      | parity_table[(tmp16 & 0x07) ^ pcpu->b]	\
      | ((tmp8 & 0x80) ? NF : 0)		\
      | ((tmp16 > 0xff) ? CF : 0);		\
  } while (0)

#define LDI()		\
  do {			\
    BLOCK_COPY();	\
    INCW(d, e);		\
    INCW(h, l);		\
  } while (0)

#define LDD()		\
  do {			\
    BLOCK_COPY();	\
    DECW(d, e);		\
    DECW(h, l);	\
  } while (0)

#define CPI()		\
  do {			\
    BLOCK_SEARCH();	\
    INCW(h, l);		\
  } while (0)

#define CPD()		\
  do {			\
    BLOCK_SEARCH();	\
    DECW(h, l);		\
  } while (0)

#define INI()					\
  do {						\
    BLOCK_INPUT1();				\
    INCW(h, l);					\
    tmp16 = tmp8 + ((pcpu->c + 1) & 0xff);	\
    BLOCK_INPUT2();				\
  } while (0)

#define IND()					\
  do {						\
    BLOCK_INPUT1();				\
    DECW(h, l);					\
    tmp16 = tmp8 + ((pcpu->c - 1) & 0xff);	\
    BLOCK_INPUT2();				\
  } while (0)

#define OUTI()		\
  do {			\
    BLOCK_OUTPUT1();	\
    INCW(h, l);		\
    BLOCK_OUTPUT2();	\
  } while (0)

#define OUTD()		\
  do {			\
    BLOCK_OUTPUT1();	\
    DECW(h, l);		\
    BLOCK_OUTPUT2();	\
  } while (0)

#define REPBC()			\
  do {				\
    if (pcpu->f & PF) {		\
      pcpu->pc -= 2;		\
    } else {			\
      pcpu->cycles -= 5;	\
      pcpu->f &= ~PF;		\
    }				\
  } while (0)

#define REPCP()					\
  do {						\
    if (pcpu->f & PF && pcpu->a != tmp8) {	\
      pcpu->pc -= 2;				\
    } else {					\
      pcpu->cycles -= 5;			\
    }						\
  } while (0)

#define REPB()			\
  do {				\
    if (pcpu->b) {		\
      pcpu->pc -= 2;		\
    } else {			\
      pcpu->cycles -= 5;	\
    }				\
  } while (0)

enum {
  SF = 0x80, ZF = 0x40, YF = 0x20, HF = 0x10,
  XF = 0x08, PF = 0x04, VF = 0x04, NF = 0x02, CF = 0x01
};

byte parity_table[] = {
  PF, 0 , 0 , PF, 0 , PF, PF, 0 , 0 , PF, PF, 0 , PF, 0 , 0 , PF,
  0 , PF, PF, 0 , PF, 0 , 0 , PF, PF, 0 , 0 , PF, 0 , PF, PF, 0,
  0 , PF, PF, 0 , PF, 0 , 0 , PF, PF, 0 , 0 , PF, 0 , PF, PF, 0,
  PF, 0 , 0 , PF, 0 , PF, PF, 0 , 0 , PF, PF, 0 , PF, 0 , 0 , PF,
  0 , PF, PF, 0 , PF, 0 , 0 , PF, PF, 0 , 0 , PF, 0 , PF, PF, 0,
  PF, 0 , 0 , PF, 0 , PF, PF, 0 , 0 , PF, PF, 0 , PF, 0 , 0 , PF,
  PF, 0 , 0 , PF, 0 , PF, PF, 0 , 0 , PF, PF, 0 , PF, 0 , 0 , PF,
  0 , PF, PF, 0 , PF, 0 , 0 , PF, PF, 0 , 0 , PF, 0 , PF, PF, 0,
  0 , PF, PF, 0 , PF, 0 , 0 , PF, PF, 0 , 0 , PF, 0 , PF, PF, 0,
  PF, 0 , 0 , PF, 0 , PF, PF, 0 , 0 , PF, PF, 0 , PF, 0 , 0 , PF,
  PF, 0 , 0 , PF, 0 , PF, PF, 0 , 0 , PF, PF, 0 , PF, 0 , 0 , PF,
  0 , PF, PF, 0 , PF, 0 , 0 , PF, PF, 0 , 0 , PF, 0 , PF, PF, 0,
  PF, 0 , 0 , PF, 0 , PF, PF, 0 , 0 , PF, PF, 0 , PF, 0 , 0 , PF,
  0 , PF, PF, 0 , PF, 0 , 0 , PF, PF, 0 , 0 , PF, 0 , PF, PF, 0,
  0 , PF, PF, 0 , PF, 0 , 0 , PF, PF, 0 , 0 , PF, 0 , PF, PF, 0,
  PF, 0 , 0 , PF, 0 , PF, PF, 0 , 0 , PF, PF, 0 , PF, 0 , 0 , PF,
};

int tstates[0x100] = {
  4,	10,	7,	6,	4,	4,	7,	4,
  4,	11,	7,	6,	4,	4,	7,	4,
  13,	10,	7,	6,	4,	4,	7,	4,
  12,	11,	7,	6,	4,	4,	7,	4,
  12,	10,	16,	6,	4,	4,	7,	4,
  12,	11,	16,	6,	4,	4,	7,	4,
  12,	10,	13,	6,	11,	11,	10,	4,
  12,	11,	13,	6,	4,	4,	7,	4,
  4,	4,	4,	4,	4,	4,	7,	4,
  4,	4,	4,	4,	4,	4,	7,	4,
  4,	4,	4,	4,	4,	4,	7,	4,
  4,	4,	4,	4,	4,	4,	7,	4,
  4,	4,	4,	4,	4,	4,	7,	4,
  4,	4,	4,	4,	4,	4,	7,	4,
  7,	7,	7,	7,	7,	7,	4,	7,
  4,	4,	4,	4,	4,	4,	7,	4,
  4,	4,	4,	4,	4,	4,	7,	4,
  4,	4,	4,	4,	4,	4,	7,	4,
  4,	4,	4,	4,	4,	4,	7,	4,
  4,	4,	4,	4,	4,	4,	7,	4,
  4,	4,	4,	4,	4,	4,	7,	4,
  4,	4,	4,	4,	4,	4,	7,	4,
  4,	4,	4,	4,	4,	4,	7,	4,
  4,	4,	4,	4,	4,	4,	7,	4,
  11,	10,	10,	10,	17,	11,	7,	11,
  11,	10,	10,	4,	17,	17,	7,	11,
  11,	10,	10,	11,	17,	11,	7,	11,
  11,	4,	10,	11,	17,	4,	7,	11,
  11,	10,	10,	19,	17,	11,	7,	11,
  11,	4,	10,	4,	17,	4,	7,	11,
  11,	10,	10,	4,	17,	11,	7,	11,
  11,	4,	10,	4,	17,	4,	7,	11
};

int tstates_cb[0x100] = {
  4,	4,	4,	4,	4,	4,	11,	4,
  4,	4,	4,	4,	4,	4,	11,	4,
  4,	4,	4,	4,	4,	4,	11,	4,
  4,	4,	4,	4,	4,	4,	11,	4,
  4,	4,	4,	4,	4,	4,	11,	4,
  4,	4,	4,	4,	4,	4,	11,	4,
  4,	4,	4,	4,	4,	4,	11,	4,
  4,	4,	4,	4,	4,	4,	11,	4,
  4,	4,	4,	4,	4,	4,	8,	4,
  4,	4,	4,	4,	4,	4,	8,	4,
  4,	4,	4,	4,	4,	4,	8,	4,
  4,	4,	4,	4,	4,	4,	8,	4,
  4,	4,	4,	4,	4,	4,	8,	4,
  4,	4,	4,	4,	4,	4,	8,	4,
  4,	4,	4,	4,	4,	4,	8,	4,
  4,	4,	4,	4,	4,	4,	8,	4,
  4,	4,	4,	4,	4,	4,	11,	4,
  4,	4,	4,	4,	4,	4,	11,	4,
  4,	4,	4,	4,	4,	4,	11,	4,
  4,	4,	4,	4,	4,	4,	11,	4,
  4,	4,	4,	4,	4,	4,	11,	4,
  4,	4,	4,	4,	4,	4,	11,	4,
  4,	4,	4,	4,	4,	4,	11,	4,
  4,	4,	4,	4,	4,	4,	11,	4,
  4,	4,	4,	4,	4,	4,	11,	4,
  4,	4,	4,	4,	4,	4,	11,	4,
  4,	4,	4,	4,	4,	4,	11,	4,
  4,	4,	4,	4,	4,	4,	11,	4,
  4,	4,	4,	4,	4,	4,	11,	4,
  4,	4,	4,	4,	4,	4,	11,	4,
  4,	4,	4,	4,	4,	4,	11,	4,
  4,	4,	4,	4,	4,	4,	11,	4
};

int tstates_ed[0x100] = {
  4,	4,	4,	4,	4,	4,	4,	4,
  4,	4,	4,	4,	4,	4,	4,	4,
  4,	4,	4,	4,	4,	4,	4,	4,
  4,	4,	4,	4,	4,	4,	4,	4,
  4,	4,	4,	4,	4,	4,	4,	4,
  4,	4,	4,	4,	4,	4,	4,	4,
  4,	4,	4,	4,	4,	4,	4,	4,
  4,	4,	4,	4,	4,	4,	4,	4,
  8,	8,	11,	16,	4,	10,	4,	5,
  8,	8,	11,	16,	4,	10,	4,	5,
  8,	8,	11,	16,	4,	10,	4,	5,
  8,	8,	11,	16,	4,	10,	4,	5,
  8,	8,	11,	16,	4,	10,	4,	10,
  8,	8,	11,	16,	4,	10,	4,	10,
  8,	8,	11,	16,	4,	10,	4,	4,
  8,	8,	11,	16,	4,	10,	4,	4,
  4,	4,	4,	4,	4,	4,	4,	4,
  4,	4,	4,	4,	4,	4,	4,	4,
  4,	4,	4,	4,	4,	4,	4,	4,
  4,	4,	4,	4,	4,	4,	4,	4,
  12,	12,	12,	12,	4,	4,	4,	4,
  12,	12,	12,	12,	4,	4,	4,	4,
  17,	17,	17,	17,	4,	4,	4,	4,
  17,	17,	17,	17,	4,	4,	4,	4,
  4,	4,	4,	4,	4,	4,	4,	4,
  4,	4,	4,	4,	4,	4,	4,	4,
  4,	4,	4,	4,	4,	4,	4,	4,
  4,	4,	4,	4,	4,	4,	4,	4,
  4,	4,	4,	4,	4,	4,	4,	4,
  4,	4,	4,	4,	4,	4,	4,	4,
  4,	4,	4,	4,	4,	4,	4,	4,
  4,	4,	4,	4,	4,	4,	4,	4
};

int tstates_dd[0x100] = {
  0,	0,	0,	0,	0,	0,	0,	0,
  0,	11,	0,	0,	0,	0,	0,	0,
  0,	0,	0,	0,	0,	0,	0,	0,
  0,	11,	0,	0,	0,	0,	0,	0,
  0,	10,	16,	6,	4,	4,	7,	0,
  0,	11,	16,	10,	4,	4,	7,	0,
  0,	0,	0,	0,	19,	19,	15,	0,
  0,	11,	0,	0,	0,	0,	0,	0,
  0,	0,	0,	0,	4,	4,	15,	0,
  0,	0,	0,	0,	4,	4,	15,	0,
  0,	0,	0,	0,	4,	4,	15,	0,
  0,	0,	0,	0,	4,	4,	15,	0,
  4,	4,	4,	4,	4,	4,	15,	4,
  4,	4,	4,	4,	4,	4,	15,	4,
  15,	15,	15,	15,	15,	15,	0,	15,
  0,	0,	0,	0,	4,	4,	15,	0,
  0,	0,	0,	0,	4,	4,	15,	0,
  0,	0,	0,	0,	4,	4,	15,	0,
  0,	0,	0,	0,	4,	4,	15,	0,
  0,	0,	0,	0,	4,	4,	15,	0,
  0,	0,	0,	0,	4,	4,	15,	0,
  0,	0,	0,	0,	4,	4,	15,	0,
  0,	0,	0,	0,	4,	4,	15,	0,
  0,	0,	0,	0,	4,	4,	15,	0,
  0,	0,	0,	0,	0,	0,	0,	0,
  0,	0,	0,	4,	0,	0,	0,	0,
  0,	0,	0,	0,	0,	0,	0,	0,
  0,	0,	0,	0,	0,	0,	0,	0,
  0,	10,	0,	15,	0,	11,	0,	0,
  0,	4,	0,	0,	0,	0,	0,	0,
  0,	0,	0,	0,	0,	0,	0,	0,
  0,	4,	0,	0,	0,	0,	0,	0
};

int tstates_ddcb[0x100] = {
  15,	15,	15,	15,	15,	15,	15,	15,
  15,	15,	15,	15,	15,	15,	15,	15,
  15,	15,	15,	15,	15,	15,	15,	15,
  15,	15,	15,	15,	15,	15,	15,	15,
  15,	15,	15,	15,	15,	15,	15,	15,
  15,	15,	15,	15,	15,	15,	15,	15,
  15,	15,	15,	15,	15,	15,	15,	15,
  15,	15,	15,	15,	15,	15,	15,	15,
  12,	12,	12,	12,	12,	12,	12,	12,
  12,	12,	12,	12,	12,	12,	12,	12,
  12,	12,	12,	12,	12,	12,	12,	12,
  12,	12,	12,	12,	12,	12,	12,	12,
  12,	12,	12,	12,	12,	12,	12,	12,
  12,	12,	12,	12,	12,	12,	12,	12,
  12,	12,	12,	12,	12,	12,	12,	12,
  12,	12,	12,	12,	12,	12,	12,	12,
  15,	15,	15,	15,	15,	15,	15,	15,
  15,	15,	15,	15,	15,	15,	15,	15,
  15,	15,	15,	15,	15,	15,	15,	15,
  15,	15,	15,	15,	15,	15,	15,	15,
  15,	15,	15,	15,	15,	15,	15,	15,
  15,	15,	15,	15,	15,	15,	15,	15,
  15,	15,	15,	15,	15,	15,	15,	15,
  15,	15,	15,	15,	15,	15,	15,	15,
  15,	15,	15,	15,	15,	15,	15,	15,
  15,	15,	15,	15,	15,	15,	15,	15,
  15,	15,	15,	15,	15,	15,	15,	15,
  15,	15,	15,	15,	15,	15,	15,	15,
  15,	15,	15,	15,	15,	15,	15,	15,
  15,	15,	15,	15,	15,	15,	15,	15,
  15,	15,	15,	15,	15,	15,	15,	15,
  15,	15,	15,	15,	15,	15,	15,	15,
};

const char *mnemonics[0x100] = {
	"NOP",	"LD BC,#h",	"LD (BC),A",	"INC BC",
	"INC B",	"DEC B",	"LD B,*h",	"RLCA",
	"EX AF,AF'",	"ADD HL,BC",	"LD A,(BC)",	"DEC BC",
	"INC C",	"DEC C",	"LD C,*h",	"RRCA",
	"DJNZ @h",	"LD DE,#h",	"LD (DE),A",	"INC DE",
	"INC D",	"DEC D",	"LD D,*h",	"RLA",
	"JR @h",	"ADD HL,DE",	"LD A,(DE)",	"DEC DE",
	"INC E",	"DEC E",	"LD E,*h",	"RRA",
	"JR NZ,@h",	"LD HL,#h",	"LD (#h),HL",	"INC HL",
	"INC H",	"DEC H",	"LD H,*h",	"DAA",
	"JR Z,@h",	"ADD HL,HL",	"LD HL,(#h)",	"DEC HL",
	"INC L",	"DEC L",	"LD L,*h",	"CPL",
	"JR NC,@h",	"LD SP,#h",	"LD (#h),A",	"INC SP",
	"INC (HL)",	"DEC (HL)",	"LD (HL),*h",	"SCF",
	"JR C,@h",	"ADD HL,SP",	"LD A,(#h)",	"DEC SP",
	"INC A",	"DEC A",	"LD A,*h",	"CCF",
	"LD B,B",	"LD B,C",	"LD B,D",	"LD B,E",
	"LD B,H",	"LD B,L",	"LD B,(HL)",	"LD B,A",
	"LD C,B",	"LD C,C",	"LD C,D",	"LD C,E",
	"LD C,H",	"LD C,L",	"LD C,(HL)",	"LD C,A",
	"LD D,B",	"LD D,C",	"LD D,D",	"LD D,E",
	"LD D,H",	"LD D,L",	"LD D,(HL)",	"LD D,A",
	"LD E,B",	"LD E,C",	"LD E,D",	"LD E,E",
	"LD E,H",	"LD E,L",	"LD E,(HL)",	"LD E,A",
	"LD H,B",	"LD H,C",	"LD H,D",	"LD H,E",
	"LD H,H",	"LD H,L",	"LD H,(HL)",	"LD H,A",
	"LD L,B",	"LD L,C",	"LD L,D",	"LD L,E",
	"LD L,H",	"LD L,L",	"LD L,(HL)",	"LD L,A",
	"LD (HL),B",	"LD (HL),C",	"LD (HL),D",	"LD (HL),E",
	"LD (HL),H",	"LD (HL),L",	"HALT",		"LD (HL),A",
	"LD A,B",	"LD A,C",	"LD A,D",	"LD A,E",
	"LD A,H",	"LD A,L",	"LD A,(HL)",	"LD A,A",
	"ADD A,B",	"ADD A,C",	"ADD A,D",	"ADD A,E",
	"ADD A,H",	"ADD A,L",	"ADD A,(HL)",	"ADD A,A",
	"ADC A,B",	"ADC A,C",	"ADC A,D",	"ADC A,E",
	"ADC A,H",	"ADC A,L",	"ADC A,(HL)",	"ADC A,A",
	"SUB B",	"SUB C",	"SUB D",	"SUB E",
	"SUB H",	"SUB L",	"SUB (HL)",	"SUB A",
	"SBC A,B",	"SBC A,C",	"SBC A,D",	"SBC A,E",
	"SBC A,H",	"SBC A,L",	"SBC A,(HL)",	"SBC A,A",
	"AND B",	"AND C",	"AND D",	"AND E",
	"AND H",	"AND L",	"AND (HL)",	"AND A",
	"XOR B",	"XOR C",	"XOR D",	"XOR E",
	"XOR H",	"XOR L",	"XOR (HL)",	"XOR A",
	"OR B",		"OR C",		"OR D",		"OR E",
	"OR H",		"OR L",		"OR (HL)",	"OR A",
	"CP B",		"CP C",		"CP D",		"CP E",
	"CP H",		"CP L",		"CP (HL)",	"CP A",
	"RET NZ",	"POP BC",	"JP NZ,#h",	"JP #h",
	"CALL NZ,#h",	"PUSH BC",	"ADD A,*h",	"RST 00h",
	"RET Z",	"RET",		"JP Z,#h",	"CB prefix",
	"CALL Z,#h",	"CALL #h",	"adc A,*H",	"RST 08h",
	"RET NC",	"POP DE",	"JP NC,#h",	"OUT (*h),A",
	"CALL NC,#h",	"PUSH DE",	"SUB *h",	"RST 10h",
	"RET C",	"EXX",		"JP C,#h",	"IN A,(*h)",
	"CALL C,#h",	"DD prefix",	"SBC A,*h",	"RST 18h",
	"RET PO",	"POP HL",	"JP PO,#h",	"EX (SP),HL",
	"CALL PO,#h",	"PUSH HL",	"AND *h",	"RST 20h",
	"RET PE",	"JP (HL)",	"JP PE,#h",	"EX DE,HL",
	"CALL PE,#h",	"ED prefix",	"XOR *h",	"RST 28h",
	"RET P",	"POP AF",	"JP P,#h",	"DI",
	"CALL P,#h",	"PUSH AF",	"OR *h",	"RST 30h",
	"RET M",	"LD SP,HL",	"JP M,#h",	"EI",
	"CALL M,#h",	"FD prefix",	"CP *h",	"RST 38h"
};

const char *mnemonics_cb[0x100] = {
	"RLC B",	"RLC C",	"RLC D",	"RLC E",
	"RLC H",	"RLC L",	"RLC (HL)",	"RLC A",
	"RRC B",	"RRC C",	"RRC D",	"RRC E",
	"RRC H",	"RRC L",	"RRC (HL)",	"RRC A",
	"RL B",		"RL C",		"RL D",		"RL E",
	"RL H",		"RL L",		"RL (HL)",	"RL A",
	"RR B",		"RR C",		"RR D",		"RR E",
	"RR H",		"RR L",		"RR (HL)",	"RR A",
	"SLA B",	"SLA C",	"SLA D",	"SLA E",
	"SLA H",	"SLA L",	"SLA (HL)",	"SLA A",
	"SRA B",	"SRA C",	"SRA D",	"SRA E",
	"SRA H",	"SRA L",	"SRA (HL)",	"SRA A",
	"SLL B",	"SLL C",	"SLL D",	"SLL E",
	"SLL H",	"SLL L",	"SLL (HL)",	"SLL A",
	"SRL B",	"SRL C",	"SRL D",	"SRL E",
	"SRL H",	"SRL L",	"SRL (HL)",	"SRL A",
	"BIT 0,B",	"BIT 0,C",	"BIT 0,D",	"BIT 0,E",
	"BIT 0,H",	"BIT 0,L",	"BIT 0,(HL)",	"BIT 0,A",
	"BIT 1,B",	"BIT 1,C",	"BIT 1,D",	"BIT 1,E",
	"BIT 1,H",	"BIT 1,L",	"BIT 1,(HL)",	"BIT 1,A",
	"BIT 2,B",	"BIT 2,C",	"BIT 2,D",	"BIT 2,E",
	"BIT 2,H",	"BIT 2,L",	"BIT 2,(HL)",	"BIT 2,A",
	"BIT 3,B",	"BIT 3,C",	"BIT 3,D",	"BIT 3,E",
	"BIT 3,H",	"BIT 3,L",	"BIT 3,(HL)",	"BIT 3,A",
	"BIT 4,B",	"BIT 4,C",	"BIT 4,D",	"BIT 4,E",
	"BIT 4,H",	"BIT 4,L",	"BIT 4,(HL)",	"BIT 4,A",
	"BIT 5,B",	"BIT 5,C",	"BIT 5,D",	"BIT 5,E",
	"BIT 5,H",	"BIT 5,L",	"BIT 5,(HL)",	"BIT 5,A",
	"BIT 6,B",	"BIT 6,C",	"BIT 6,D",	"BIT 6,E",
	"BIT 6,H",	"BIT 6,L",	"BIT 6,(HL)",	"BIT 6,A",
	"BIT 7,B",	"BIT 7,C",	"BIT 7,D",	"BIT 7,E",
	"BIT 7,H",	"BIT 7,L",	"BIT 7,(HL)",	"BIT 7,A",
	"RES 0,B",	"RES 0,C",	"RES 0,D",	"RES 0,E",
	"RES 0,H",	"RES 0,L",	"RES 0,(HL)",	"RES 0,A",
	"RES 1,B",	"RES 1,C",	"RES 1,D",	"RES 1,E",
	"RES 1,H",	"RES 1,L",	"RES 1,(HL)",	"RES 1,A",
	"RES 2,B",	"RES 2,C",	"RES 2,D",	"RES 2,E",
	"RES 2,H",	"RES 2,L",	"RES 2,(HL)",	"RES 2,A",
	"RES 3,B",	"RES 3,C",	"RES 3,D",	"RES 3,E",
	"RES 3,H",	"RES 3,L",	"RES 3,(HL)",	"RES 3,A",
	"RES 4,B",	"RES 4,C",	"RES 4,D",	"RES 4,E",
	"RES 4,H",	"RES 4,L",	"RES 4,(HL)",	"RES 4,A",
	"RES 5,B",	"RES 5,C",	"RES 5,D",	"RES 5,E",
	"RES 5,H",	"RES 5,L",	"RES 5,(HL)",	"RES 5,A",
	"RES 6,B",	"RES 6,C",	"RES 6,D",	"RES 6,E",
	"RES 6,H",	"RES 6,L",	"RES 6,(HL)",	"RES 6,A",
	"RES 7,B",	"RES 7,C",	"RES 7,D",	"RES 7,E",
	"RES 7,H",	"RES 7,L",	"RES 7,(HL)",	"RES 7,A",
	"SET 0,B",	"SET 0,C",	"SET 0,D",	"SET 0,E",
	"SET 0,H",	"SET 0,L",	"SET 0,(HL)",	"SET 0,A",
	"SET 1,B",	"SET 1,C",	"SET 1,D",	"SET 1,E",
	"SET 1,H",	"SET 1,L",	"SET 1,(HL)",	"SET 1,A",
	"SET 2,B",	"SET 2,C",	"SET 2,D",	"SET 2,E",
	"SET 2,H",	"SET 2,L",	"SET 2,(HL)",	"SET 2,A",
	"SET 3,B",	"SET 3,C",	"SET 3,D",	"SET 3,E",
	"SET 3,H",	"SET 3,L",	"SET 3,(HL)",	"SET 3,A",
	"SET 4,B",	"SET 4,C",	"SET 4,D",	"SET 4,E",
	"SET 4,H",	"SET 4,L",	"SET 4,(HL)",	"SET 4,A",
	"SET 5,B",	"SET 5,C",	"SET 5,D",	"SET 5,E",
	"SET 5,H",	"SET 5,L",	"SET 5,(HL)",	"SET 5,A",
	"SET 6,B",	"SET 6,C",	"SET 6,D",	"SET 6,E",
	"SET 6,H",	"SET 6,L",	"SET 6,(HL)",	"SET 6,A",
	"SET 7,B",	"SET 7,C",	"SET 7,D",	"SET 7,E",
	"SET 7,H",	"SET 7,L",	"SET 7,(HL)",	"SET 7,A"
};

const char *mnemonics_ed[0x100] = {
	"NOP",		"NOP",		"NOP",		"NOP",
	"NOP",		"NOP",		"NOP",		"NOP",
	"NOP",		"NOP",		"NOP",		"NOP",
	"NOP",		"NOP",		"NOP",		"NOP",
	"NOP",		"NOP",		"NOP",		"NOP",
	"NOP",		"NOP",		"NOP",		"NOP",
	"NOP",		"NOP",		"NOP",		"NOP",
	"NOP",		"NOP",		"NOP",		"NOP",
	"NOP",		"NOP",		"NOP",		"NOP",
	"NOP",		"NOP",		"NOP",		"NOP",
	"NOP",		"NOP",		"NOP",		"NOP",
	"NOP",		"NOP",		"NOP",		"NOP",
	"NOP",		"NOP",		"NOP",		"NOP",
	"NOP",		"NOP",		"NOP",		"NOP",
	"NOP",		"NOP",		"NOP",		"NOP",
	"NOP",		"NOP",		"NOP",		"NOP",
	"IN B,(C)",	"OUT (C),B",	"SBC HL,BC",	"LD (#h),BC",
	"NEG",		"RETN",		"IM 0",		"LD I,A",
	"IN C,(C)",	"OUT (C),C",	"ADC HL,BC",	"LD BC,(#h)",
	"NEG",		"RETI",		"IM 0",		"LD R,A",
	"IN D,(C)",	"OUT (C),D",	"SBC HL,DE",	"LD (#h),DE",
	"NEG",		"RETN",		"IM 1",		"LD A,I",
	"IN E,(C)",	"OUT (C),E",	"ADC HL,DE",	"LD DE,(#h)",
	"NEG",		"RETN",		"IM 2",		"LD A,R",
	"IN H,(C)",	"OUT (C),H",	"SBC HL,HL",	"LD (#h),HL",
	"NEG",		"RETN",		"IM 0",		"RRD",
	"IN L,(C)",	"OUT (C),L",	"ADC HL,HL",	"LD HL,(#h)",
	"NEG",		"RETN",		"IM 0",		"RLD",
	"IN F,(C)",	"OUT (C),0",	"SBC HL,SP",	"LD (#h),SP",
	"NEG",		"RETN",		"IM 1",		"NOP",
	"IN A,(C)",	"OUT (C),A",	"ADC HL,SP",	"LD SP,(#h)",
	"NEG",		"RETN",		"IM 2",		"NOP",
	"NOP",		"NOP",		"NOP",		"NOP",
	"NOP",		"NOP",		"NOP",		"NOP",
	"NOP",		"NOP",		"NOP",		"NOP",
	"NOP",		"NOP",		"NOP",		"NOP",
	"NOP",		"NOP",		"NOP",		"NOP",
	"NOP",		"NOP",		"NOP",		"NOP",
	"NOP",		"NOP",		"NOP",		"NOP",
	"NOP",		"NOP",		"NOP",		"NOP",
	"LDI",		"CPI",		"INI",		"OUTI",
	"NOP",		"NOP",		"NOP",		"NOP",
	"LDD",		"CPD",		"IND",		"OUTD",
	"NOP",		"NOP",		"NOP",		"NOP",
	"LDIR",		"CPIR",		"INIR",		"OTIR",
	"NOP",		"NOP",		"NOP",		"NOP",
	"LDDR",		"CPDR",		"INDR",		"OTDR",
	"NOP",		"NOP",		"NOP",		"NOP",
	"NOP",		"NOP",		"NOP",		"NOP",
	"NOP",		"NOP",		"NOP",		"NOP",
	"NOP",		"NOP",		"NOP",		"NOP",
	"NOP",		"NOP",		"NOP",		"NOP",
	"NOP",		"NOP",		"NOP",		"NOP",
	"NOP",		"NOP",		"NOP",		"NOP",
	"NOP",		"NOP",		"NOP",		"NOP",
	"NOP",		"NOP",		"NOP",		"NOP",
	"NOP",		"NOP",		"NOP",		"NOP",
	"NOP",		"NOP",		"NOP",		"NOP",
	"NOP",		"NOP",		"NOP",		"NOP",
	"NOP",		"NOP",		"NOP",		"NOP",
	"NOP",		"NOP",		"NOP",		"NOP",
	"NOP",		"NOP",		"NOP",		"NOP",
	"NOP",		"NOP",		"NOP",		"NOP",
	"NOP",		"NOP",		"NOP",		"NOP"
};

const char *mnemonics_dd[0x100] = {
	"NOP",		"LD BC,#h",	"LD (BC),A",	"INC BC",
	"INC B",	"DEC B",	"LD B,*h",	"RLCA",
	"EX AF,AF'",	"ADD I%,BC",	"LD A,(BC)",	"DEC BC",
	"INC C",	"DEC C",	"LD C,*h",	"RRCA",
	"DJNZ @h",	"LD DE,#h",	"LD (DE),A",	"INC DE",
	"INC D",	"DEC D",	"LD D,*h",	"RLA",
	"JR @h",	"ADD I%,DE",	"LD A,(DE)",	"DEC DE",
	"INC E",	"DEC E",	"LD E,*h",	"RRA",
	"JR NZ,@h",	"LD I%,#h",	"LD (#h),I%",	"INC I%",
	"INC I%h",	"DEC I%h",	"LD I%h,*h",	"DAA",
	"JR Z,@h",	"ADD I%,I%",	"LD I%,(#h)",	"DEC I%",
	"INC I%l",	"DEC I%l",	"LD I%l,*h",	"CPL",
	"JR NC,@h",	"LD SP,#h",	"LD (#h),A",	"INC SP",
	"INC (I%^h)",	"DEC (I%^h)",	"LD (I%^h),*h",	"SCF",
	"JR C,@h",	"ADD I%,SP",	"LD A,(#h)",	"DEC SP",
	"INC A",	"DEC A",	"LD A,*h",	"CCF",
	"LD B,B",	"LD B,C",	"LD B,D",	"LD B,E",
	"LD B,I%h",	"LD B,I%l",	"LD B,(I%^h)",	"LD B,A",
	"LD C,B",	"LD C,C",	"LD C,D",	"LD C,E",
	"LD C,I%h",	"LD C,I%l",	"LD C,(I%^h)",	"LD C,A",
	"LD D,B",	"LD D,C",	"LD D,D",	"LD D,E",
	"LD D,I%h",	"LD D,I%l",	"LD D,(I%^h)",	"LD D,A",
	"LD E,B",	"LD E,C",	"LD E,D",	"LD E,E",
	"LD E,I%h",	"LD E,I%l",	"LD E,(I%^h)",	"LD E,A",
	"LD I%h,B",	"LD I%h,C",	"LD I%h,D",	"LD I%h,E",
	"LD I%h,I%h",	"LD I%h,I%l",	"LD H,(I%^h)",	"LD I%h,A",
	"LD I%l,B",	"LD I%l,C",	"LD I%l,D",	"LD I%l,E",
	"LD I%l,I%h",	"LD I%l,I%l",	"LD L,(I%^h)",	"LD I%l,A",
	"LD (I%^h),B",	"LD (I%^h),C",	"LD (I%^h),D",	"LD (I%^h),E",
	"LD (I%^h),H",	"LD (I%^h),L",	"HALT",		"LD (I%^h),A",
	"LD A,B",	"LD A,C",	"LD A,D",	"LD A,E",
	"LD A,I%h",	"LD A,I%l",	"LD A,(I%^h)",	"LD A,A",
	"ADD A,B",	"ADD A,C",	"ADD A,D",	"ADD A,E",
	"ADD A,I%h",	"ADD A,I%l",	"ADD A,(I%^h)",	"ADD A,A",
	"ADC A,B",	"ADC A,C",	"ADC A,D",	"ADC A,E",
	"ADC A,I%h",	"ADC A,I%l",	"ADC A,(I%^h)",	"ADC A,A",
	"SUB B",	"SUB C",	"SUB D",	"SUB E",
	"SUB I%h",	"SUB I%l",	"SUB (I%^h)",	"SUB A",
	"SBC A,B",	"SBC A,C",	"SBC A,D",	"SBC A,E",
	"SBC A,I%h",	"SBC A,I%l",	"SBC A,(I%^h)",	"SBC A,A",
	"AND B",	"AND C",	"AND D",	"AND E",
	"AND I%h",	"AND I%l",	"AND (I%^h)",	"AND A",
	"XOR B",	"XOR C",	"XOR D",	"XOR E",
	"XOR I%h",	"XOR I%l",	"XOR (I%^h)",	"XOR A",
	"OR B",		"OR C",		"OR D",		"OR E",
	"OR I%h",	"OR I%l",	"OR (I%^h)",	"OR A",
	"CP B",		"CP C",		"CP D",		"CP E",
	"CP I%h",	"CP I%l",	"CP (I%^h)",	"CP A",
	"RET NZ",	"POP BC",	"JP NZ,#h",	"JP #h",
	"CALL NZ,#h",	"PUSH BC",	"ADD A,#h",	"RST 00h",
	"RET Z",	"RET",		"JP Z,#h",	"CB prefix",
	"CALL Z,#h",	"CALL #h",	"adc A,*H",	"RST 08h",
	"RET NC",	"POP DE",	"JP NC,#h",	"OUT (*h),A",
	"CALL NC,#h",	"PUSH DE",	"SUB *h",	"RST 10h",
	"RET C",	"EXX",		"JP C,#h",	"IN A,(*h)",
	"CALL C,#h",	"DD prefix",	"SBC A,*h",	"RST 18h",
	"RET PO",	"POP I%",	"JP PO,#h",	"EX (SP),I%",
	"CALL PO,#h",	"PUSH I%",	"AND *h",	"RST 20h",
	"RET PE",	"JP (HL)",	"JP PE,#h",	"EX DE,HL",
	"CALL PE,#h",	"ED prefix",	"XOR *h",	"RST 28h",
	"RET P",	"POP AF",	"JP P,#h",	"DI",
	"CALL P,#h",	"PUSH AF",	"OR *h",	"RST 30h",
	"RET M",	"LD SP,I%",	"JP M,#h",	"EI",
	"CALL M,#h",	"FD prefix",	"CP *h",	"RST 38h"
};

const char *mnemonics_ddcb[0x100] = {
	"RLC (I%^h),B",	"RLC (I%^h),C",	"RLC (I%^h),D",	"RLC (I%^h),E",
	"RLC (I%^h),H",	"RLC (I%^h),L",	"RLC (I%^h)",	"RLC (I%^h),A",
	"RRC (I%^h),B",	"RRC (I%^h),C",	"RRC (I%^h),D",	"RRC (I%^h),E",
	"RRC (I%^h),H",	"RRC (I%^h),L",	"RRC (I%^h)",	"RRC (I%^h),A",
	"RL (I%^h),B",	"RL (I%^h),C",	"RL (I%^h),D",	"RL (I%^h),E",
	"RL (I%^h),H",	"RL (I%^h),L",	"RL (I%^h)",	"RL (I%^h),A",
	"RR (I%^h),B",	"RR (I%^h),C",	"RR (I%^h),D",	"RR (I%^h),E",
	"RR (I%^h),H",	"RR (I%^h),L",	"RR (I%^h)",	"RR (I%^h),A",
	"SLA (I%^h),B",	"SLA (I%^h),C",	"SLA (I%^h),D",	"SLA (I%^h),E",
	"SLA (I%^h),H",	"SLA (I%^h),L",	"SLA (I%^h)",	"SLA (I%^h),A",
	"SRA (I%^h),B",	"SRA (I%^h),C",	"SRA (I%^h),D",	"SRA (I%^h),E",
	"SRA (I%^h),H",	"SRA (I%^h),L",	"SRA (I%^h)",	"SRA (I%^h),A",
	"SLL (I%^h),B",	"SLL (I%^h),C",	"SLL (I%^h),D",	"SLL (I%^h),E",
	"SLL (I%^h),H",	"SLL (I%^h),L",	"SLL (I%^h)",	"SLL (I%^h),A",
	"SRL (I%^h),B",	"SRL (I%^h),C",	"SRL (I%^h),D",	"SRL (I%^h),E",
	"SRL (I%^h),H",	"SRL (I%^h),L",	"SRL (I%^h)",	"SRL (I%^h),A",
	"BIT 0,(I%^h)",	"BIT 0,(I%^h)",	"BIT 0,(I%^h)",	"BIT 0,(I%^h)",
	"BIT 0,(I%^h)",	"BIT 0,(I%^h)",	"BIT 0,(I%^h)",	"BIT 0,(I%^h)",
	"BIT 1,(I%^h)",	"BIT 1,(I%^h)",	"BIT 1,(I%^h)",	"BIT 1,(I%^h)",
	"BIT 1,(I%^h)",	"BIT 1,(I%^h)",	"BIT 1,(I%^h)",	"BIT 1,(I%^h)",
	"BIT 2,(I%^h)",	"BIT 2,(I%^h)",	"BIT 2,(I%^h)",	"BIT 2,(I%^h)",
	"BIT 2,(I%^h)",	"BIT 2,(I%^h)",	"BIT 2,(I%^h)",	"BIT 2,(I%^h)",
	"BIT 3,(I%^h)",	"BIT 3,(I%^h)",	"BIT 3,(I%^h)",	"BIT 3,(I%^h)",
	"BIT 3,(I%^h)",	"BIT 3,(I%^h)",	"BIT 3,(I%^h)",	"BIT 3,(I%^h)",
	"BIT 4,(I%^h)",	"BIT 4,(I%^h)",	"BIT 4,(I%^h)",	"BIT 4,(I%^h)",
	"BIT 4,(I%^h)",	"BIT 4,(I%^h)",	"BIT 4,(I%^h)",	"BIT 4,(I%^h)",
	"BIT 5,(I%^h)",	"BIT 5,(I%^h)",	"BIT 5,(I%^h)",	"BIT 5,(I%^h)",
	"BIT 5,(I%^h)",	"BIT 5,(I%^h)",	"BIT 5,(I%^h)",	"BIT 5,(I%^h)",
	"BIT 6,(I%^h)",	"BIT 6,(I%^h)",	"BIT 6,(I%^h)",	"BIT 6,(I%^h)",
	"BIT 6,(I%^h)",	"BIT 6,(I%^h)",	"BIT 6,(I%^h)",	"BIT 6,(I%^h)",
	"BIT 7,(I%^h)",	"BIT 7,(I%^h)",	"BIT 7,(I%^h)",	"BIT 7,(I%^h)",
	"BIT 7,(I%^h)",	"BIT 7,(I%^h)",	"BIT 7,(I%^h)",	"BIT 7,(I%^h)",
	"RES 0,(I%^h),B","RES 0,(I%^h),C","RES 0,(I%^h),D","RES 0,(I%^h),E",
	"RES 0,(I%^h),H","RES 0,(I%^h),L","RES 0,(I%^h)","RES 0,(I%^h),A",
	"RES 1,(I%^h),B","RES 1,(I%^h),C","RES 1,(I%^h),D","RES 1,(I%^h),E",
	"RES 1,(I%^h),H","RES 1,(I%^h),L","RES 1,(I%^h)","RES 1,(I%^h),A",
	"RES 2,(I%^h),B","RES 2,(I%^h),C","RES 2,(I%^h),D","RES 2,(I%^h),E",
	"RES 2,(I%^h),H","RES 2,(I%^h),L","RES 2,(I%^h)","RES 2,(I%^h),A",
	"RES 3,(I%^h),B","RES 3,(I%^h),C","RES 3,(I%^h),D","RES 3,(I%^h),E",
	"RES 3,(I%^h),H","RES 3,(I%^h),L","RES 3,(I%^h)","RES 3,(I%^h),A",
	"RES 4,(I%^h),B","RES 4,(I%^h),C","RES 4,(I%^h),D","RES 4,(I%^h),E",
	"RES 4,(I%^h),H","RES 4,(I%^h),L","RES 4,(I%^h)","RES 4,(I%^h),A",
	"RES 5,(I%^h),B","RES 5,(I%^h),C","RES 5,(I%^h),D","RES 5,(I%^h),E",
	"RES 5,(I%^h),H","RES 5,(I%^h),L","RES 5,(I%^h)","RES 5,(I%^h),A",
	"RES 6,(I%^h),B","RES 6,(I%^h),C","RES 6,(I%^h),D","RES 6,(I%^h),E",
	"RES 6,(I%^h),H","RES 6,(I%^h),L","RES 6,(I%^h)","RES 6,(I%^h),A",
	"RES 7,(I%^h),B","RES 7,(I%^h),C","RES 7,(I%^h),D","RES 7,(I%^h),E",
	"RES 7,(I%^h),H","RES 7,(I%^h),L","RES 7,(I%^h)","RES 7,(I%^h),A",
	"SET 0,(I%^h),B","SET 0,(I%^h),C","SET 0,(I%^h),D","SET 0,(I%^h),E",
	"SET 0,(I%^h),H","SET 0,(I%^h),L","SET 0,(I%^h)","SET 0,(I%^h),A",
	"SET 1,(I%^h),B","SET 1,(I%^h),C","SET 1,(I%^h),D","SET 1,(I%^h),E",
	"SET 1,(I%^h),H","SET 1,(I%^h),L","SET 1,(I%^h)","SET 1,(I%^h),A",
	"SET 2,(I%^h),B","SET 2,(I%^h),C","SET 2,(I%^h),D","SET 2,(I%^h),E",
	"SET 2,(I%^h),H","SET 2,(I%^h),L","SET 2,(I%^h)","SET 2,(I%^h),A",
	"SET 3,(I%^h),B","SET 3,(I%^h),C","SET 3,(I%^h),D","SET 3,(I%^h),E",
	"SET 3,(I%^h),H","SET 3,(I%^h),L","SET 3,(I%^h)","SET 3,(I%^h),A",
	"SET 4,(I%^h),B","SET 4,(I%^h),C","SET 4,(I%^h),D","SET 4,(I%^h),E",
	"SET 4,(I%^h),H","SET 4,(I%^h),L","SET 4,(I%^h)","SET 4,(I%^h),A",
	"SET 5,(I%^h),B","SET 5,(I%^h),C","SET 5,(I%^h),D","SET 5,(I%^h),E",
	"SET 5,(I%^h),H","SET 5,(I%^h),L","SET 5,(I%^h)","SET 5,(I%^h),A",
	"SET 6,(I%^h),B","SET 6,(I%^h),C","SET 6,(I%^h),D","SET 6,(I%^h),E",
	"SET 6,(I%^h),H","SET 6,(I%^h),L","SET 6,(I%^h)","SET 6,(I%^h),A",
	"SET 7,(I%^h),B","SET 7,(I%^h),C","SET 7,(I%^h),D","SET 7,(I%^h),E",
	"SET 7,(I%^h),H","SET 7,(I%^h),L","SET 7,(I%^h)","SET 7,(I%^h),A",
};

static byte fetch(z80 *pcpu);
static void exec_code(z80 *pcpu, byte op);
static int search_code(const char **mnem, char ixiy, char *input, byte *data, word address);
static int upperhex(int value, int mask);

/*
 * initialize CPU
 */
void z80_reset(z80 *pcpu)
{
  memset(pcpu, 0, sizeof(*pcpu));
  pcpu->a = pcpu->f = 0xff;
  pcpu->b = pcpu->c = 0xff;
  pcpu->d = pcpu->e = 0xff;
  pcpu->h = pcpu->l = 0xff;

  pcpu->alt_a = pcpu->alt_f = 0xff;
  pcpu->alt_b = pcpu->alt_c = 0xff;
  pcpu->alt_d = pcpu->alt_e = 0xff;
  pcpu->alt_h = pcpu->alt_l = 0xff;

  pcpu->ixh = pcpu->ixl = 0xff;
  pcpu->iyh = pcpu->iyl = 0xff;

  pcpu->i = 0;
  pcpu->r = 0;
  pcpu->sp = 0;
  pcpu->pc = 0;

  pcpu->iff1 = 0;
  pcpu->iff2 = 0;
  pcpu->im = 0;
  pcpu->ei = 0;
  pcpu->m1 = 0;
  pcpu->halt = 0;
}

/*
 * Z80 main routine
 */
void z80_main(z80 *pcpu)
{
  byte op;

  pcpu->cycles = 0;
  op = fetch(pcpu);

  if (pcpu->ei) {
    pcpu->ei = 0;
  }
  exec_code(pcpu, op);
}

/*
 * nonmaskable interrupt
 */
void z80_nmi(z80 *pcpu)
{
  pcpu->halt = 0;
  pcpu->iff1 = 0;
  pcpu->r = (pcpu->r & 0x80) + ((pcpu->r + 1) & 0x7f);
  pcpu->cycles = 13;		/* 2 + 11(rst) */
  RST(0x0066);
}

/*
 * maskable interrupt
 */
void z80_int(z80 *pcpu, byte vector)
{
  word address;

  pcpu->halt = 0;
  pcpu->iff1 = 0;
  pcpu->iff2 = 0;
  pcpu->r = (pcpu->r & 0x80) + ((pcpu->r + 1) & 0x7f);

  switch (pcpu->im) {
  case 0:
    pcpu->cycles = 2;
    exec_code(pcpu, vector);
    break;

  case 1:
    pcpu->cycles = 2;
    exec_code(pcpu, 0xff);	/* rst 38h */
    break;
      
  case 2:
    pcpu->cycles = 19;		/* 2 + 3(M2) + 3(M2) + 11(rst) */
    address = vector + (pcpu->i << 8);
    RST(z80_read(address) + (z80_read(address + 1) << 8));
    break;
  }
}

/*
 * disassemble
 */
int z80_dasm(char *disasm, word address)
{
  int i;
  int bytes;
  byte op, prefix;
  char *pos;

  disasm[0] = '\0';
  op = z80_read(address);

  switch (op) {
  case 0xcb:
    strcpy(disasm, mnemonics_cb[z80_read(++address)]);
    bytes = 2;
    break;

  case 0xed:
    strcpy(disasm, mnemonics_ed[z80_read(++address)]);
    bytes = 2;
    break;

  case 0xdd:
  case 0xfd:
    bytes = 1;
    do {
      prefix = op;
      op = z80_read(++address);
      bytes++;
    } while (op == 0xdd || op == 0xfd);

    switch (op) {
    case 0xcb:
      strcpy(disasm, mnemonics_ddcb[z80_read(address + 2)]);
      bytes++;
      break;

    case 0xed:
      strcpy(disasm, mnemonics_ed[z80_read(++address)]);
      bytes++;
      break;

    default:
      strcpy(disasm, mnemonics_dd[op]);
      break;
    }

    for (i = 0; i < 2; i++) {
      if (pos = strchr(disasm, '%')) {
	*pos = (prefix == 0xdd ? 'X' : 'Y');
      }
    }
    break;

  default:
    strcpy(disasm, mnemonics[op]);
    bytes = 1;
    break;
  }

  if (pos = strchr(disasm, '*')) {
    memmove(pos + 3, pos + 2, strlen(pos) - 1);
    sprintf(pos, "%02X", z80_read(++address));
    *(pos + 2) = 'h';
    bytes++;
  }

  if (pos = strchr(disasm, '@')) {
    memmove(pos + 5, pos + 2, strlen(pos) - 1);
    sprintf(pos, "%04X",
	    ((int8_t)z80_read((address + 1) & 0xffff) + address + 2) & 0xffff);
    *(pos + 4) = 'h';
    bytes++;
  }

  if (pos = strchr(disasm, '^')) {
    memmove(pos + 4, pos + 2, strlen(pos) - 1);
    i = z80_read(++address);
    if (i < 0x80) {
      sprintf(pos, "+%02X", i);
    } else {
      sprintf(pos, "-%02X", 0x100 - i);
    }
    *(pos + 3) = 'h';
    bytes++;
  }

  if (pos = strchr(disasm, '#')) {
    memmove(pos + 5, pos + 2, strlen(pos) - 1);
    sprintf(pos, "%02X%02X",
	    z80_read((address + 2) & 0xffff),
	    z80_read((address + 1) & 0xffff));
    *(pos + 4) = 'h';
    bytes += 2;
  }
  return bytes;
}

/*
 * assemble
 */
int z80_asm(char *input, byte *data, word address)
{
  size_t i, j;
  int bytes;
  char *pos;

  i = strspn(input, " ");
  for (j = strlen(input) - i; j > 0; j--) {
    if (input[i + j - 1] != ' ') {
      break;
    }
  }
  memmove(input, &input[i], j);
  input[j] = '\0';
	     
  while (pos = strstr(input, ", ")) {
    memmove(pos + 1, pos + 2, strlen(pos + 1));
  }
  while (pos = strstr(input, " ,")) {
    memmove(pos, pos + 1, strlen(pos));
  }

  for (i = 0; i < strlen(input); i++) {
    input[i] = toupper((int)input[i]);
  }

  
  if (bytes = search_code(mnemonics, 0, input, data, address)) {
    return bytes;
  }

  if (bytes = search_code(mnemonics_cb, 0, input, &data[1], address)) {
    data[0] = 0xcb;
    return bytes + 1;
  }

  if (bytes = search_code(mnemonics_ed, 0, input, &data[1], address)) {
    data[0] = 0xed;
    return bytes + 1;
  }

  if (bytes = search_code(mnemonics_dd, 'X', input, &data[1], address)) {
    data[0] = 0xdd;
    return bytes + 1;
  }

  if (bytes = search_code(mnemonics_ddcb, 'X', input, &data[2], address)) {
    data[0] = 0xdd;
    data[1] = 0xcb;
    i = data[2];
    data[2] = data[3];
    data[3] = i;
    return bytes + 2;
  }

  if (bytes = search_code(mnemonics_dd, 'Y', input, &data[1], address)) {
    data[0] = 0xfd;
    return bytes + 1;
  }

  if (bytes = search_code(mnemonics_ddcb, 'Y', input, &data[2], address)) {
    data[0] = 0xfd;
    data[1] = 0xcb;
    i = data[2];
    data[2] = data[3];
    data[3] = i;
    return bytes + 2;
  }

  return 0;
}

/*
 * fetch op code
 */
byte fetch(z80 *pcpu)
{
  byte op;

  pcpu->m1 = 1;
  op = z80_read(pcpu->pc++);
  pcpu->r = (pcpu->r & 0x80) + ((pcpu->r + 1) & 0x7f);
  pcpu->m1 = 0;
  return op;
}

/*
 * execute
 */
void exec_code(z80 *pcpu, byte op)
{
  byte tmp8;
  word tmp16;
  uint32_t tmp32;

  pcpu->cycles += tstates[op];

  switch (op) {
  case 0x00:						/* nop */
    break;

  case 0x01:						/* ld bc,nn */
    pcpu->c = z80_read(pcpu->pc++);
    pcpu->b = z80_read(pcpu->pc++);
    break;

  case 0x11:						/* ld de,nn */
    pcpu->e = z80_read(pcpu->pc++);
    pcpu->d = z80_read(pcpu->pc++);
    break;

  case 0x21:						/* ld hl,nn */
    pcpu->l = z80_read(pcpu->pc++);
    pcpu->h = z80_read(pcpu->pc++);
    break;

  case 0x31:						/* ld sp,nn */
    pcpu->sp = z80_read(pcpu->pc++);
    pcpu->sp += z80_read(pcpu->pc++) << 8;
    break;

  case 0x02:	z80_write(BC, pcpu->a);		break;	/* ld (bc),a */
  case 0x12:	z80_write(DE, pcpu->a);		break;	/* ld (de),a */
  case 0x22:						/* ld (nn),hl */
    tmp16 = z80_read(pcpu->pc++);
    tmp16 += z80_read(pcpu->pc++) << 8;
    z80_write(tmp16,     pcpu->l);
    z80_write(tmp16 + 1, pcpu->h);
    break;

  case 0x32:						/* ld (nn),a */
    tmp16 = z80_read(pcpu->pc++);
    tmp16 += z80_read(pcpu->pc++) << 8;
    z80_write(tmp16, pcpu->a);
    break;

  case 0x03:	INCW(b, c);			break;	/* inc bc */
  case 0x13:	INCW(d, e);			break;	/* inc de */
  case 0x23:	INCW(h, l);			break;	/* inc hl */
  case 0x33:	pcpu->sp++;			break;	/* inc sp */

  case 0x04:	INC(pcpu->b);			break;	/* inc b */
  case 0x0c:	INC(pcpu->c);			break;	/* inc c */
  case 0x14:	INC(pcpu->d);			break;	/* inc d */
  case 0x1c:	INC(pcpu->e);			break;	/* inc e */
  case 0x24:	INC(pcpu->h);			break;	/* inc h */
  case 0x2c:	INC(pcpu->l);			break;	/* inc l */
  case 0x34:	MREG(INC);			break;	/* inc (hl) */
  case 0x3c:	INC(pcpu->a);			break;	/* inc a */

  case 0x05:	DEC(pcpu->b);			break;	/* dec b */
  case 0x0d:	DEC(pcpu->c);			break;	/* dec c */
  case 0x15:	DEC(pcpu->d);			break;	/* dec d */
  case 0x1d:	DEC(pcpu->e);			break;	/* dec e */
  case 0x25:	DEC(pcpu->h);			break;	/* dec h */
  case 0x2d:	DEC(pcpu->l);			break;	/* dec l */
  case 0x35:	MREG(DEC);			break;	/* dec (hl) */
  case 0x3d:	DEC(pcpu->a);			break;	/* dec a */

  case 0x06:	pcpu->b = z80_read(pcpu->pc++);	break;	/* ld b,n */
  case 0x0e:	pcpu->c = z80_read(pcpu->pc++);	break;	/* ld c,n */
  case 0x16:	pcpu->d = z80_read(pcpu->pc++);	break;	/* ld d,n */
  case 0x1e:	pcpu->e = z80_read(pcpu->pc++);	break;	/* ld e,n */
  case 0x26:	pcpu->h = z80_read(pcpu->pc++);	break;	/* ld h,n */
  case 0x2e:	pcpu->l = z80_read(pcpu->pc++);	break;	/* ld l,n */
  case 0x36:	z80_write(HL, z80_read(pcpu->pc++));	break;	/*ld (hl),n */
  case 0x3e:	pcpu->a = z80_read(pcpu->pc++);	break;	/* ld a,n */

  case 0x07:						/* rlca */
    pcpu->a = (pcpu->a << 1) + (pcpu->a >> 7);
    pcpu->f
      = (pcpu->f & SF)
      | (pcpu->f & ZF)
      | (pcpu->a & YF)
      | 0
      | (pcpu->a & XF)
      | (pcpu->f & PF)
      | 0
      | ((pcpu->a & 0x01) ? CF : 0);
    break;

  case 0x0f:						/* rrca */
    pcpu->a = (pcpu->a >> 1) + (pcpu->a << 7);
    pcpu->f
      = (pcpu->f & SF)
      | (pcpu->f & ZF)
      | (pcpu->a & YF)
      | 0
      | (pcpu->a & XF)
      | (pcpu->f & PF)
      | 0
      | ((pcpu->a & 0x80) ? CF : 0);
    break;

  case 0x17:						/* rla */
    tmp8 = pcpu->a;
    pcpu->a = (pcpu->a << 1) + ((pcpu->f & CF) ? 0x01 : 0);
    pcpu->f
      = (pcpu->f & SF)
      | (pcpu->f & ZF)
      | (pcpu->a & YF)
      | 0
      | (pcpu->a & XF)
      | (pcpu->f & PF)
      | 0
      | ((tmp8 & 0x80) ? CF : 0);
    break;

  case 0x1f:						/* rra */
    tmp8 = pcpu->a;
    pcpu->a = (pcpu->a >> 1) + ((pcpu->f & CF) ? 0x80 : 0);
    pcpu->f
      = (pcpu->f & SF)
      | (pcpu->f & ZF)
      | (pcpu->a & YF)
      | 0
      | (pcpu->a & XF)
      | (pcpu->f & PF)
      | 0
      | ((tmp8 & 0x01) ? CF : 0);
    break;

  case 0x08:						/* ex af,af' */
    tmp8 = pcpu->a;
    pcpu->a = pcpu->alt_a;
    pcpu->alt_a = tmp8;
    tmp8 = pcpu->f;
    pcpu->f = pcpu->alt_f;
    pcpu->alt_f = tmp8;
    break;

  case 0x09:	ADDW(h, l, BC);			break;	/* add hl,bc */
  case 0x19:	ADDW(h, l, DE);			break;	/* add hl,de */
  case 0x29:	ADDW(h, l, HL);			break;	/* add hl,hl */
  case 0x39:	ADDW(h, l, pcpu->sp);		break;	/* add hl,sp */

  case 0x0a:	pcpu->a = z80_read(BC);		break;	/* ld a,(bc) */
  case 0x1a:	pcpu->a = z80_read(DE);		break;	/* ld a,(de) */
  case 0x2a:						/* ld hl,(nn) */
    tmp16 = z80_read(pcpu->pc++);
    tmp16 += z80_read(pcpu->pc++) << 8;
    pcpu->l = z80_read(tmp16);
    pcpu->h = z80_read(tmp16 + 1);
    break;
  case 0x3a:						/* ld a,(nn) */
    tmp16 = z80_read(pcpu->pc++);
    tmp16 += z80_read(pcpu->pc++) << 8;
    pcpu->a = z80_read(tmp16);
    break;

  case 0x0b:	DECW(b, c);			break;	/* dec bc */
  case 0x1b:	DECW(d, e);			break;	/* dec de */
  case 0x2b:	DECW(h, l);			break;	/* dec hl */
  case 0x3b:	pcpu->sp--;			break;	/* dec sp */

  case 0x10:						/* djnz e */
    pcpu->b--;
    if (pcpu->b) {
      JR();
    } else {
      z80_read(pcpu->pc++);
      pcpu->cycles -= 5;
    }
    break;
  case 0x18:	JR();				break;	/* jr e */
  case 0x20:	JRCND(ZF, 0);			break;	/* jr nz,e */
  case 0x28:	JRCND(ZF, ZF);			break;	/* jr z,e */
  case 0x30:	JRCND(CF, 0);			break;	/* jr nc,e */
  case 0x38:	JRCND(CF, CF);			break;	/* jr c,e */

  case 0x27:						/* daa */
    {
      byte high, low, diff;

      high = pcpu->a >> 4;
      low = pcpu->a & 0x0f;
      if ((pcpu->f & HF) || low >= 0xa) {
	diff = 0x06;
      } else {
	diff = 0;
      }
      if ((pcpu->f & CF) || high >= 0xa || (high == 0x9 && low >= 0xa)) {
	diff += 0x60;
      }

      if (pcpu->f & NF) {
	pcpu->a -= diff;
      } else {
	pcpu->a += diff;
      }

      pcpu->f
	= FLAGS(pcpu->a)
	| ((((pcpu->f & NF) == 0 && low >= 0xa)
	    || (pcpu->f & NF) && (pcpu->f & HF) && low <= 0x5)
	   ? HF : 0)
	| (pcpu->f & NF)
	| ((diff >= 0x60) ? CF : 0);
      break;
    }

  case 0x2f:						/* cpl */
    pcpu->a = ~pcpu->a;
    pcpu->f
      = (pcpu->f & SF)
      | (pcpu->f & ZF)
      | (pcpu->a & YF)
      | HF
      | (pcpu->a & XF)
      | (pcpu->f & VF)
      | NF
      | (pcpu->f & CF);
    break;

  case 0x37:						/* scf */
    pcpu->f
      = (pcpu->f & SF)
      | (pcpu->f & ZF)
      | (pcpu->a & YF)
      | 0
      | (pcpu->a & XF)
      | (pcpu->f & VF)
      | 0
      | CF;
    break;

  case 0x3f:						/* ccf */
    pcpu->f
      = (pcpu->f & SF)
      | (pcpu->f & ZF)
      | (pcpu->a & YF)
      | ((pcpu->f & CF) ? HF : 0)
      | (pcpu->a & XF)
      | (pcpu->f & VF)
      | 0
      | ((pcpu->f & CF) ? 0 : CF);
    break;

  case 0x40:	pcpu->b = pcpu->b;		break;	/* ld b,b */
  case 0x41:	pcpu->b = pcpu->c;		break;	/* ld b,c */
  case 0x42:	pcpu->b = pcpu->d;		break;	/* ld b,d */
  case 0x43:	pcpu->b = pcpu->e;		break;	/* ld b,e */
  case 0x44:	pcpu->b = pcpu->h;		break;	/* ld b,h */
  case 0x45:	pcpu->b = pcpu->l;		break;	/* ld b,l */
  case 0x46:	pcpu->b = z80_read(HL);		break;	/* ld b,(hl) */
  case 0x47:	pcpu->b = pcpu->a;		break;	/* ld b,a */

  case 0x48:	pcpu->c = pcpu->b;		break;	/* ld c,b */
  case 0x49:	pcpu->c = pcpu->c;		break;	/* ld c,c */
  case 0x4a:	pcpu->c = pcpu->d;		break;	/* ld c,d */
  case 0x4b:	pcpu->c = pcpu->e;		break;	/* ld c,e */
  case 0x4c:	pcpu->c = pcpu->h;		break;	/* ld c,h */
  case 0x4d:	pcpu->c = pcpu->l;		break;	/* ld c,l */
  case 0x4e:	pcpu->c = z80_read(HL);		break;	/* ld c,(hl) */
  case 0x4f:	pcpu->c = pcpu->a;		break;	/* ld c,a */

  case 0x50:	pcpu->d = pcpu->b;		break;	/* ld d,b */
  case 0x51:	pcpu->d = pcpu->c;		break;	/* ld d,c */
  case 0x52:	pcpu->d = pcpu->d;		break;	/* ld d,d */
  case 0x53:	pcpu->d = pcpu->e;		break;	/* ld d,e */
  case 0x54:	pcpu->d = pcpu->h;		break;	/* ld d,h */
  case 0x55:	pcpu->d = pcpu->l;		break;	/* ld d,l */
  case 0x56:	pcpu->d = z80_read(HL);		break;	/* ld d,(hl) */
  case 0x57:	pcpu->d = pcpu->a;		break;	/* ld d,a */

  case 0x58:	pcpu->e = pcpu->b;		break;	/* ld e,b */
  case 0x59:	pcpu->e = pcpu->c;		break;	/* ld e,c */
  case 0x5a:	pcpu->e = pcpu->d;		break;	/* ld e,d */
  case 0x5b:	pcpu->e = pcpu->e;		break;	/* ld e,e */
  case 0x5c:	pcpu->e = pcpu->h;		break;	/* ld e,h */
  case 0x5d:	pcpu->e = pcpu->l;		break;	/* ld e,l */
  case 0x5e:	pcpu->e = z80_read(HL);		break;	/* ld e,(hl) */
  case 0x5f:	pcpu->e = pcpu->a;		break;	/* ld e,a */

  case 0x60:	pcpu->h = pcpu->b;		break;	/* ld h,b */
  case 0x61:	pcpu->h = pcpu->c;		break;	/* ld h,c */
  case 0x62:	pcpu->h = pcpu->d;		break;	/* ld h,d */
  case 0x63:	pcpu->h = pcpu->e;		break;	/* ld h,e */
  case 0x64:	pcpu->h = pcpu->h;		break;	/* ld h,h */
  case 0x65:	pcpu->h = pcpu->l;		break;	/* ld h,l */
  case 0x66:	pcpu->h = z80_read(HL);		break;	/* ld h,(hl) */
  case 0x67:	pcpu->h = pcpu->a;		break;	/* ld h,a */

  case 0x68:	pcpu->l = pcpu->b;		break;	/* ld l,b */
  case 0x69:	pcpu->l = pcpu->c;		break;	/* ld l,c */
  case 0x6a:	pcpu->l = pcpu->d;		break;	/* ld l,d */
  case 0x6b:	pcpu->l = pcpu->e;		break;	/* ld l,e */
  case 0x6c:	pcpu->l = pcpu->h;		break;	/* ld l,h */
  case 0x6d:	pcpu->l = pcpu->l;		break;	/* ld l,l */
  case 0x6e:	pcpu->l = z80_read(HL);		break;	/* ld l,(hl) */
  case 0x6f:	pcpu->l = pcpu->a;		break;	/* ld l,a */

  case 0x70:	z80_write(HL, pcpu->b);		break;	/* ld (hl),b */
  case 0x71:	z80_write(HL, pcpu->c);		break;	/* ld (hl),c */
  case 0x72:	z80_write(HL, pcpu->d);		break;	/* ld (hl),d */
  case 0x73:	z80_write(HL, pcpu->e);		break;	/* ld (hl),e */
  case 0x74:	z80_write(HL, pcpu->h);		break;	/* ld (hl),h */
  case 0x75:	z80_write(HL, pcpu->l);		break;	/* ld (hl),l */
  case 0x76:						/* halt */
    pcpu->halt = 1;
    pcpu->pc--;
    break;
  case 0x77:	z80_write(HL, pcpu->a);		break;	/* ld (hl),a */

  case 0x78:	pcpu->a = pcpu->b;		break;	/* ld a,b */
  case 0x79:	pcpu->a = pcpu->c;		break;	/* ld a,c */
  case 0x7a:	pcpu->a = pcpu->d;		break;	/* ld a,d */
  case 0x7b:	pcpu->a = pcpu->e;		break;	/* ld a,e */
  case 0x7c:	pcpu->a = pcpu->h;		break;	/* ld a,h */
  case 0x7d:	pcpu->a = pcpu->l;		break;	/* ld a,l */
  case 0x7e:	pcpu->a = z80_read(HL);		break;	/* ld a,(hl) */
  case 0x7f:	pcpu->a = pcpu->a;		break;	/* ld a,a */

  case 0x80:	ADD(pcpu->b);			break;	/* add a,b */
  case 0x81:	ADD(pcpu->c);			break;	/* add a,c */
  case 0x82:	ADD(pcpu->d);			break;	/* add a,d */
  case 0x83:	ADD(pcpu->e);			break;	/* add a,e */
  case 0x84:	ADD(pcpu->h);			break;	/* add a,h */
  case 0x85:	ADD(pcpu->l);			break;	/* add a,l */
  case 0x86:	ADD(z80_read(HL));		break;	/* add a,(hl) */
  case 0x87:	ADD(pcpu->a);			break;	/* add a,a */

  case 0x88:	ADC(pcpu->b);			break;	/* adc a,b */
  case 0x89:	ADC(pcpu->c);			break;	/* adc a,c */
  case 0x8a:	ADC(pcpu->d);			break;	/* adc a,d */
  case 0x8b:	ADC(pcpu->e);			break;	/* adc a,e */
  case 0x8c:	ADC(pcpu->h);			break;	/* adc a,h */
  case 0x8d:	ADC(pcpu->l);			break;	/* adc a,l */
  case 0x8e:	ADC(z80_read(HL));		break;	/* adc a,(hl) */
  case 0x8f:	ADC(pcpu->a);			break;	/* adc a,a */

  case 0x90:	SUB(pcpu->b);			break;	/* sub b */
  case 0x91:	SUB(pcpu->c);			break;	/* sub c */
  case 0x92:	SUB(pcpu->d);			break;	/* sub d */
  case 0x93:	SUB(pcpu->e);			break;	/* sub e */
  case 0x94:	SUB(pcpu->h);			break;	/* sub h */
  case 0x95:	SUB(pcpu->l);			break;	/* sub l */
  case 0x96:	SUB(z80_read(HL));		break;	/* sub (hl) */
  case 0x97:	SUB(pcpu->a);			break;	/* sub a */

  case 0x98:	SBC(pcpu->b);			break;	/* sbc a,b */
  case 0x99:	SBC(pcpu->c);			break;	/* sbc a,c */
  case 0x9a:	SBC(pcpu->d);			break;	/* sbc a,d */
  case 0x9b:	SBC(pcpu->e);			break;	/* sbc a,e */
  case 0x9c:	SBC(pcpu->h);			break;	/* sbc a,h */
  case 0x9d:	SBC(pcpu->l);			break;	/* sbc a,l */
  case 0x9e:	SBC(z80_read(HL));		break;	/* sbc a,(hl) */
  case 0x9f:	SBC(pcpu->a);			break;	/* sbc a,a */

  case 0xa0:	AND(pcpu->b);			break;	/* and b */
  case 0xa1:	AND(pcpu->c);			break;	/* and c */
  case 0xa2:	AND(pcpu->d);			break;	/* and d */
  case 0xa3:	AND(pcpu->e);			break;	/* and e */
  case 0xa4:	AND(pcpu->h);			break;	/* and h */
  case 0xa5:	AND(pcpu->l);			break;	/* and l */
  case 0xa6:	AND(z80_read(HL));		break;	/* and (hl) */
  case 0xa7:	AND(pcpu->a);			break;	/* and a */

  case 0xa8:	XOR(pcpu->b);			break;	/* xor b */
  case 0xa9:	XOR(pcpu->c);			break;	/* xor c */
  case 0xaa:	XOR(pcpu->d);			break;	/* xor d */
  case 0xab:	XOR(pcpu->e);			break;	/* xor e */
  case 0xac:	XOR(pcpu->h);			break;	/* xor h */
  case 0xad:	XOR(pcpu->l);			break;	/* xor l */
  case 0xae:	XOR(z80_read(HL));		break;	/* xor (hl) */
  case 0xaf:	XOR(pcpu->a);			break;	/* xor a */

  case 0xb0:	OR(pcpu->b);			break;	/* or b */
  case 0xb1:	OR(pcpu->c);			break;	/* or c */
  case 0xb2:	OR(pcpu->d);			break;	/* or d */
  case 0xb3:	OR(pcpu->e);			break;	/* or e */
  case 0xb4:	OR(pcpu->h);			break;	/* or h */
  case 0xb5:	OR(pcpu->l);			break;	/* or l */
  case 0xb6:	OR(z80_read(HL));		break;	/* or (hl) */
  case 0xb7:	OR(pcpu->a);			break;	/* or a */

  case 0xb8:	CP(pcpu->b);			break;	/* cp b */
  case 0xb9:	CP(pcpu->c);			break;	/* cp c */
  case 0xba:	CP(pcpu->d);			break;	/* cp d */
  case 0xbb:	CP(pcpu->e);			break;	/* cp e */
  case 0xbc:	CP(pcpu->h);			break;	/* cp h */
  case 0xbd:	CP(pcpu->l);			break;	/* cp l */
  case 0xbe:	CP(z80_read(HL));		break;	/* cp (hl) */
  case 0xbf:	CP(pcpu->a);			break;	/* cp a */

  case 0xc0:	RETCND(ZF, 0);			break;	/* ret nz */
  case 0xc8:	RETCND(ZF, ZF);			break;	/* ret z */
  case 0xd0:	RETCND(CF, 0);			break;	/* ret nc */
  case 0xd8:	RETCND(CF, CF);			break;	/* ret c */
  case 0xe0:	RETCND(PF, 0);			break;	/* ret po */
  case 0xe8:	RETCND(PF, PF);			break;	/* ret pe */
  case 0xf0:	RETCND(SF, 0);			break;	/* ret p */
  case 0xf8:	RETCND(SF, SF);			break;	/* ret m */

  case 0xc1:	POP(b, c);			break;	/* pop bc */
  case 0xd1:	POP(d, e);			break;	/* pop de */
  case 0xe1:	POP(h, l);			break;	/* pop hl */
  case 0xf1:	POP(a, f);			break;	/* pop af */

  case 0xc2:	JPCND(ZF, 0);			break;	/* jp nz,nn */
  case 0xca:	JPCND(ZF, ZF);			break;	/* jp z,nn */
  case 0xd2:	JPCND(CF, 0);			break;	/* jp nc,nn */
  case 0xda:	JPCND(CF, CF);			break;	/* jp c,nn */
  case 0xe2:	JPCND(PF, 0);			break;	/* jp po,nn */
  case 0xea:	JPCND(PF, PF);			break;	/* jp pe,nn */
  case 0xf2:	JPCND(SF, 0);			break;	/* jp p,nn */
  case 0xfa:	JPCND(SF, SF);			break;	/* jp m,nn */

  case 0xc4:	CALLCND(ZF, 0);			break;	/* call nz,nn */
  case 0xcc:	CALLCND(ZF, ZF);		break;	/* call z,nn*/
  case 0xd4:	CALLCND(CF, 0);			break;	/* call nc,nn */
  case 0xdc:	CALLCND(CF, CF);		break;	/* call c,nn */
  case 0xe4:	CALLCND(PF, 0);			break;	/* call po,nn */
  case 0xec:	CALLCND(PF, PF);		break;	/* call pe,nn */
  case 0xf4:	CALLCND(SF, 0);			break;	/* call p,nn*/
  case 0xfc:	CALLCND(SF, SF);		break;	/* call m,nn */

  case 0xc5:	PUSH(b, c);			break;	/* push bc */
  case 0xd5:	PUSH(d, e);			break;	/* push de */
  case 0xe5:	PUSH(h, l);			break;	/* push hl */
  case 0xf5:	PUSH(a, f);			break;	/* push af */

  case 0xc6:	ADD(z80_read(pcpu->pc++));	break;	/* add a,n */
  case 0xce:	ADC(z80_read(pcpu->pc++));	break;	/* adc a,n */
  case 0xd6:	SUB(z80_read(pcpu->pc++));	break;	/* sub n */
  case 0xde:	SBC(z80_read(pcpu->pc++));	break;	/* sbc a,n */
  case 0xe6:	AND(z80_read(pcpu->pc++));	break;	/* and n */
  case 0xee:	XOR(z80_read(pcpu->pc++));	break;	/* xor n */
  case 0xf6:	OR(z80_read(pcpu->pc++));	break;	/* or n */
  case 0xfe:	CP(z80_read(pcpu->pc++));	break;	/* cp n */

  case 0xc7:	RST(0x0000);			break;	/* rst 00h */
  case 0xcf:	RST(0x0008);			break;	/* rst 08h */
  case 0xd7:	RST(0x0010);			break;	/* rst 10h */
  case 0xdf:	RST(0x0018);			break;	/* rst 18h */
  case 0xe7:	RST(0x0020);			break;	/* rst 20h */
  case 0xef:	RST(0x0028);			break;	/* rst 28h */
  case 0xf7:	RST(0x0030);			break;	/* rst 30h */
  case 0xff:	RST(0x0038);			break;	/* rst 38h */

  case 0xc3:	JPCND(0, 0);			break;	/* jp nn */

  case 0xc9:	RET();				break;	/* ret */

  case 0xcd:	CALL();				break;	/* call nn */

  case 0xd3:						/* out (n),a */
    z80_out(z80_read(pcpu->pc++) + (pcpu->a << 8), pcpu->a);
    break;

  case 0xd9:						/* exx */
    tmp8 = pcpu->b;
    pcpu->b = pcpu->alt_b;
    pcpu->alt_b = tmp8;
    tmp8 = pcpu->c;
    pcpu->c = pcpu->alt_c;
    pcpu->alt_c = tmp8;
    tmp8 = pcpu->d;
    pcpu->d = pcpu->alt_d;
    pcpu->alt_d = tmp8;
    tmp8 = pcpu->e;
    pcpu->e = pcpu->alt_e;
    pcpu->alt_e = tmp8;
    tmp8 = pcpu->h;
    pcpu->h = pcpu->alt_h;
    pcpu->alt_h = tmp8;
    tmp8 = pcpu->l;
    pcpu->l = pcpu->alt_l;
    pcpu->alt_l = tmp8;
    break;

  case 0xdb:						/* in a,(n) */
    pcpu->a = z80_in(z80_read(pcpu->pc++) + (pcpu->a << 8));
    break;

  case 0xe3:						/* ex (sp),hl */
    tmp8 = z80_read(pcpu->sp);
    z80_write(pcpu->sp, pcpu->l);
    pcpu->l = tmp8;
    tmp8 = z80_read(pcpu->sp + 1);
    z80_write(pcpu->sp + 1, pcpu->h);
    pcpu->h = tmp8;
    break;

  case 0xe9:						/* jp (hl) */
    pcpu->pc = HL;
    break;

  case 0xeb:						/* ex de,hl */
    tmp8 = pcpu->d;
    pcpu->d = pcpu->h;
    pcpu->h = tmp8;
    tmp8 = pcpu->e;
    pcpu->e = pcpu->l;
    pcpu->l = tmp8;
    break;

  case 0xf3:						/* di */
    pcpu->iff1 = 0;
    pcpu->iff2 = 0;
    break;

  case 0xf9:						/* ld sp,hl */
    pcpu->sp = HL;
    break;

  case 0xfb:						/* ei */
    if (pcpu->iff1 == 0 && pcpu->ei == 0) {
      pcpu->iff1 = 1;
      pcpu->iff2 = 1;
      pcpu->ei = 1;
    }
    break;

  case 0xcb:
    op = fetch(pcpu);
    pcpu->cycles += tstates_cb[op];

    switch (op) {

    case 0x00:	RLC(pcpu->b);			break;	/* rlc b */
    case 0x01:	RLC(pcpu->c);			break;	/* rlc c */
    case 0x02:	RLC(pcpu->d);			break;	/* rlc d */
    case 0x03:	RLC(pcpu->e);			break;	/* rlc e */
    case 0x04:	RLC(pcpu->h);			break;	/* rlc h */
    case 0x05:	RLC(pcpu->l);			break;	/* rlc l */
    case 0x06:	MREG(RLC);			break;	/* rlc (hl) */
    case 0x07:	RLC(pcpu->a);			break;	/* rlc a */

    case 0x08:	RRC(pcpu->b);			break;	/* rrc b */
    case 0x09:	RRC(pcpu->c);			break;	/* rrc c */
    case 0x0a:	RRC(pcpu->d);			break;	/* rrc d */
    case 0x0b:	RRC(pcpu->e);			break;	/* rrc e */
    case 0x0c:	RRC(pcpu->h);			break;	/* rrc h */
    case 0x0d:	RRC(pcpu->l);			break;	/* rrc l */
    case 0x0e:	MREG(RRC);			break;	/* rrc (hl) */
    case 0x0f:	RRC(pcpu->a);			break;	/* rrc a */

    case 0x10:	RL(pcpu->b);			break;	/* rl b */
    case 0x11:	RL(pcpu->c);			break;	/* rl c */
    case 0x12:	RL(pcpu->d);			break;	/* rl d */
    case 0x13:	RL(pcpu->e);			break;	/* rl e */
    case 0x14:	RL(pcpu->h);			break;	/* rl h */
    case 0x15:	RL(pcpu->l);			break;	/* rl l */
    case 0x16:	MREG(RL);			break;	/* rl (hl) */
    case 0x17:	RL(pcpu->a);			break;	/* rl a */

    case 0x18:	RR(pcpu->b);			break;	/* rr b */
    case 0x19:	RR(pcpu->c);			break;	/* rr c */
    case 0x1a:	RR(pcpu->d);			break;	/* rr d */
    case 0x1b:	RR(pcpu->e);			break;	/* rr e */
    case 0x1c:	RR(pcpu->h);			break;	/* rr h */
    case 0x1d:	RR(pcpu->l);			break;	/* rr l */
    case 0x1e:	MREG(RR);			break;	/* rr (hl) */
    case 0x1f:	RR(pcpu->a);			break;	/* rr a */

    case 0x20:	SLA(pcpu->b);			break;	/* sla b */
    case 0x21:	SLA(pcpu->c);			break;	/* sla c */
    case 0x22:	SLA(pcpu->d);			break;	/* sla d */
    case 0x23:	SLA(pcpu->e);			break;	/* sla e */
    case 0x24:	SLA(pcpu->h);			break;	/* sla h */
    case 0x25:	SLA(pcpu->l);			break;	/* sla l */
    case 0x26:	MREG(SLA);			break;	/* sla (hl) */
    case 0x27:	SLA(pcpu->a);			break;	/* sla a */

    case 0x28:	SRA(pcpu->b);			break;	/* sra b */
    case 0x29:	SRA(pcpu->c);			break;	/* sra c */
    case 0x2a:	SRA(pcpu->d);			break;	/* sra d */
    case 0x2b:	SRA(pcpu->e);			break;	/* sra e */
    case 0x2c:	SRA(pcpu->h);			break;	/* sra h */
    case 0x2d:	SRA(pcpu->l);			break;	/* sra l */
    case 0x2e:	MREG(SRA);			break;	/* sra (hl) */
    case 0x2f:	SRA(pcpu->a);			break;	/* sra a */

    case 0x30:	SLL(pcpu->b);			break;	/* sll b */
    case 0x31:	SLL(pcpu->c);			break;	/* sll c */
    case 0x32:	SLL(pcpu->d);			break;	/* sll d */
    case 0x33:	SLL(pcpu->e);			break;	/* sll e */
    case 0x34:	SLL(pcpu->h);			break;	/* sll h */
    case 0x35:	SLL(pcpu->l);			break;	/* sll l */
    case 0x36:	MREG(SLL);			break;	/* sll (hl) */
    case 0x37:	SLL(pcpu->a);			break;	/* sll a */

    case 0x38:	SRL(pcpu->b);			break;	/* srl b */
    case 0x39:	SRL(pcpu->c);			break;	/* srl c */
    case 0x3a:	SRL(pcpu->d);			break;	/* srl d */
    case 0x3b:	SRL(pcpu->e);			break;	/* srl e */
    case 0x3c:	SRL(pcpu->h);			break;	/* srl h */
    case 0x3d:	SRL(pcpu->l);			break;	/* srl l */
    case 0x3e:	MREG(SRL);			break;	/* srl (hl) */
    case 0x3f:	SRL(pcpu->a);			break;	/* srl a */

    case 0x40:	BIT(0, pcpu->b);		break;	/* bit 0,b */
    case 0x41:	BIT(0, pcpu->c);		break;	/* bit 0,c */
    case 0x42:	BIT(0, pcpu->d);		break;	/* bit 0,d */
    case 0x43:	BIT(0, pcpu->e);		break;	/* bit 0,e */
    case 0x44:	BIT(0, pcpu->h);		break;	/* bit 0,h */
    case 0x45:	BIT(0, pcpu->l);		break;	/* bit 0,l */
    case 0x46:	BITM(0);			break;	/* bit 0,(hl) */
    case 0x47:	BIT(0, pcpu->a);		break;	/* bit 0,a */
    case 0x48:	BIT(1, pcpu->b);		break;	/* bit 1,b */
    case 0x49:	BIT(1, pcpu->c);		break;	/* bit 1,c */
    case 0x4a:	BIT(1, pcpu->d);		break;	/* bit 1,d */
    case 0x4b:	BIT(1, pcpu->e);		break;	/* bit 1,e */
    case 0x4c:	BIT(1, pcpu->h);		break;	/* bit 1,h */
    case 0x4d:	BIT(1, pcpu->l);		break;	/* bit 1,l */
    case 0x4e:	BITM(1);			break;	/* bit 1,(hl) */
    case 0x4f:	BIT(1, pcpu->a);		break;	/* bit 1,a */
    case 0x50:	BIT(2, pcpu->b);		break;	/* bit 2,b */
    case 0x51:	BIT(2, pcpu->c);		break;	/* bit 2,c */
    case 0x52:	BIT(2, pcpu->d);		break;	/* bit 2,d */
    case 0x53:	BIT(2, pcpu->e);		break;	/* bit 2,e */
    case 0x54:	BIT(2, pcpu->h);		break;	/* bit 2,h */
    case 0x55:	BIT(2, pcpu->l);		break;	/* bit 2,l */
    case 0x56:	BITM(2);			break;	/* bit 2,(hl) */
    case 0x57:	BIT(2, pcpu->a);		break;	/* bit 2,a */
    case 0x58:	BIT(3, pcpu->b);		break;	/* bit 3,b */
    case 0x59:	BIT(3, pcpu->c);		break;	/* bit 3,c */
    case 0x5a:	BIT(3, pcpu->d);		break;	/* bit 3,d */
    case 0x5b:	BIT(3, pcpu->e);		break;	/* bit 3,e */
    case 0x5c:	BIT(3, pcpu->h);		break;	/* bit 3,h */
    case 0x5d:	BIT(3, pcpu->l);		break;	/* bit 3,l */
    case 0x5e:	BITM(3);			break;	/* bit 3,(hl) */
    case 0x5f:	BIT(3, pcpu->a);		break;	/* bit 3,a */
    case 0x60:	BIT(4, pcpu->b);		break;	/* bit 4,b */
    case 0x61:	BIT(4, pcpu->c);		break;	/* bit 4,c */
    case 0x62:	BIT(4, pcpu->d);		break;	/* bit 4,d */
    case 0x63:	BIT(4, pcpu->e);		break;	/* bit 4,e */
    case 0x64:	BIT(4, pcpu->h);		break;	/* bit 4,h */
    case 0x65:	BIT(4, pcpu->l);		break;	/* bit 4,l */
    case 0x66:	BITM(4);			break;	/* bit 4,(hl) */
    case 0x67:	BIT(4, pcpu->a);		break;	/* bit 4,a */
    case 0x68:	BIT(5, pcpu->b);		break;	/* bit 5,b */
    case 0x69:	BIT(5, pcpu->c);		break;	/* bit 5,c */
    case 0x6a:	BIT(5, pcpu->d);		break;	/* bit 5,d */
    case 0x6b:	BIT(5, pcpu->e);		break;	/* bit 5,e */
    case 0x6c:	BIT(5, pcpu->h);		break;	/* bit 5,h */
    case 0x6d:	BIT(5, pcpu->l);		break;	/* bit 5,l */
    case 0x6e:	BITM(5);			break;	/* bit 5,(hl) */
    case 0x6f:	BIT(5, pcpu->a);		break;	/* bit 5,a */
    case 0x70:	BIT(6, pcpu->b);		break;	/* bit 6,b */
    case 0x71:	BIT(6, pcpu->c);		break;	/* bit 6,c */
    case 0x72:	BIT(6, pcpu->d);		break;	/* bit 6,d */
    case 0x73:	BIT(6, pcpu->e);		break;	/* bit 6,e */
    case 0x74:	BIT(6, pcpu->h);		break;	/* bit 6,h */
    case 0x75:	BIT(6, pcpu->l);		break;	/* bit 6,l */
    case 0x76:	BITM(6);			break;	/* bit 6,(hl) */
    case 0x77:	BIT(6, pcpu->a);		break;	/* bit 6,a */
    case 0x78:	BIT(7, pcpu->b);		break;	/* bit 7,b */
    case 0x79:	BIT(7, pcpu->c);		break;	/* bit 7,c */
    case 0x7a:	BIT(7, pcpu->d);		break;	/* bit 7,d */
    case 0x7b:	BIT(7, pcpu->e);		break;	/* bit 7,e */
    case 0x7c:	BIT(7, pcpu->h);		break;	/* bit 7,h */
    case 0x7d:	BIT(7, pcpu->l);		break;	/* bit 7,l */
    case 0x7e:	BITM(7);			break;	/* bit 7,(hl) */
    case 0x7f:	BIT(7, pcpu->a);		break;	/* bit 7,a */

    case 0x80:	RES(0, pcpu->b);		break;	/* res 0,b */
    case 0x81:	RES(0, pcpu->c);		break;	/* res 0,c */
    case 0x82:	RES(0, pcpu->d);		break;	/* res 0,d */
    case 0x83:	RES(0, pcpu->e);		break;	/* res 0,e */
    case 0x84:	RES(0, pcpu->h);		break;	/* res 0,h */
    case 0x85:	RES(0, pcpu->l);		break;	/* res 0,l */
    case 0x86:	RESM(0);			break;	/* res 0,(hl) */
    case 0x87:	RES(0, pcpu->a);		break;	/* res 0,a */
    case 0x88:	RES(1, pcpu->b);		break;	/* res 1,b */
    case 0x89:	RES(1, pcpu->c);		break;	/* res 1,c */
    case 0x8a:	RES(1, pcpu->d);		break;	/* res 1,d */
    case 0x8b:	RES(1, pcpu->e);		break;	/* res 1,e */
    case 0x8c:	RES(1, pcpu->h);		break;	/* res 1,h */
    case 0x8d:	RES(1, pcpu->l);		break;	/* res 1,l */
    case 0x8e:	RESM(1);			break;	/* res 1,(hl) */
    case 0x8f:	RES(1, pcpu->a);		break;	/* res 1,a */
    case 0x90:	RES(2, pcpu->b);		break;	/* res 2,b */
    case 0x91:	RES(2, pcpu->c);		break;	/* res 2,c */
    case 0x92:	RES(2, pcpu->d);		break;	/* res 2,d */
    case 0x93:	RES(2, pcpu->e);		break;	/* res 2,e */
    case 0x94:	RES(2, pcpu->h);		break;	/* res 2,h */
    case 0x95:	RES(2, pcpu->l);		break;	/* res 2,l */
    case 0x96:	RESM(2);			break;	/* res 2,(hl) */
    case 0x97:	RES(2, pcpu->a);		break;	/* res 2,a */
    case 0x98:	RES(3, pcpu->b);		break;	/* res 3,b */
    case 0x99:	RES(3, pcpu->c);		break;	/* res 3,c */
    case 0x9a:	RES(3, pcpu->d);		break;	/* res 3,d */
    case 0x9b:	RES(3, pcpu->e);		break;	/* res 3,e */
    case 0x9c:	RES(3, pcpu->h);		break;	/* res 3,h */
    case 0x9d:	RES(3, pcpu->l);		break;	/* res 3,l */
    case 0x9e:	RESM(3);			break;	/* res 3,(hl) */
    case 0x9f:	RES(3, pcpu->a);		break;	/* res 3,a */
    case 0xa0:	RES(4, pcpu->b);		break;	/* res 4,b */
    case 0xa1:	RES(4, pcpu->c);		break;	/* res 4,c */
    case 0xa2:	RES(4, pcpu->d);		break;	/* res 4,d */
    case 0xa3:	RES(4, pcpu->e);		break;	/* res 4,e */
    case 0xa4:	RES(4, pcpu->h);		break;	/* res 4,h */
    case 0xa5:	RES(4, pcpu->l);		break;	/* res 4,l */
    case 0xa6:	RESM(4);			break;	/* res 4,(hl) */
    case 0xa7:	RES(4, pcpu->a);		break;	/* res 4,a */
    case 0xa8:	RES(5, pcpu->b);		break;	/* res 5,b */
    case 0xa9:	RES(5, pcpu->c);		break;	/* res 5,c */
    case 0xaa:	RES(5, pcpu->d);		break;	/* res 5,d */
    case 0xab:	RES(5, pcpu->e);		break;	/* res 5,e */
    case 0xac:	RES(5, pcpu->h);		break;	/* res 5,h */
    case 0xad:	RES(5, pcpu->l);		break;	/* res 5,l */
    case 0xae:	RESM(5);			break;	/* res 5,(hl) */
    case 0xaf:	RES(5, pcpu->a);		break;	/* res 5,a */
    case 0xb0:	RES(6, pcpu->b);		break;	/* res 6,b */
    case 0xb1:	RES(6, pcpu->c);		break;	/* res 6,c */
    case 0xb2:	RES(6, pcpu->d);		break;	/* res 6,d */
    case 0xb3:	RES(6, pcpu->e);		break;	/* res 6,e */
    case 0xb4:	RES(6, pcpu->h);		break;	/* res 6,h */
    case 0xb5:	RES(6, pcpu->l);		break;	/* res 6,l */
    case 0xb6:	RESM(6);			break;	/* res 6,(hl) */
    case 0xb7:	RES(6, pcpu->a);		break;	/* res 6,a */
    case 0xb8:	RES(7, pcpu->b);		break;	/* res 7,b */
    case 0xb9:	RES(7, pcpu->c);		break;	/* res 7,c */
    case 0xba:	RES(7, pcpu->d);		break;	/* res 7,d */
    case 0xbb:	RES(7, pcpu->e);		break;	/* res 7,e */
    case 0xbc:	RES(7, pcpu->h);		break;	/* res 7,h */
    case 0xbd:	RES(7, pcpu->l);		break;	/* res 7,l */
    case 0xbe:	RESM(7);			break;	/* res 7,(hl) */
    case 0xbf:	RES(7, pcpu->a);		break;	/* res 7,a */

    case 0xc0:	SET(0, pcpu->b);		break;	/* set 0,b */
    case 0xc1:	SET(0, pcpu->c);		break;	/* set 0,c */
    case 0xc2:	SET(0, pcpu->d);		break;	/* set 0,d */
    case 0xc3:	SET(0, pcpu->e);		break;	/* set 0,e */
    case 0xc4:	SET(0, pcpu->h);		break;	/* set 0,h */
    case 0xc5:	SET(0, pcpu->l);		break;	/* set 0,l */
    case 0xc6:	SETM(0);			break;	/* set 0,(hl) */
    case 0xc7:	SET(0, pcpu->a);		break;	/* set 0,a */
    case 0xc8:	SET(1, pcpu->b);		break;	/* set 1,b */
    case 0xc9:	SET(1, pcpu->c);		break;	/* set 1,c */
    case 0xca:	SET(1, pcpu->d);		break;	/* set 1,d */
    case 0xcb:	SET(1, pcpu->e);		break;	/* set 1,e */
    case 0xcc:	SET(1, pcpu->h);		break;	/* set 1,h */
    case 0xcd:	SET(1, pcpu->l);		break;	/* set 1,l */
    case 0xce:	SETM(1);			break;	/* set 1,(hl) */
    case 0xcf:	SET(1, pcpu->a);		break;	/* set 1,a */
    case 0xd0:	SET(2, pcpu->b);		break;	/* set 2,b */
    case 0xd1:	SET(2, pcpu->c);		break;	/* set 2,c */
    case 0xd2:	SET(2, pcpu->d);		break;	/* set 2,d */
    case 0xd3:	SET(2, pcpu->e);		break;	/* set 2,e */
    case 0xd4:	SET(2, pcpu->h);		break;	/* set 2,h */
    case 0xd5:	SET(2, pcpu->l);		break;	/* set 2,l */
    case 0xd6:	SETM(2);			break;	/* set 2,(hl) */
    case 0xd7:	SET(2, pcpu->a);		break;	/* set 2,a */
    case 0xd8:	SET(3, pcpu->b);		break;	/* set 3,b */
    case 0xd9:	SET(3, pcpu->c);		break;	/* set 3,c */
    case 0xda:	SET(3, pcpu->d);		break;	/* set 3,d */
    case 0xdb:	SET(3, pcpu->e);		break;	/* set 3,e */
    case 0xdc:	SET(3, pcpu->h);		break;	/* set 3,h */
    case 0xdd:	SET(3, pcpu->l);		break;	/* set 3,l */
    case 0xde:	SETM(3);			break;	/* set 3,(hl) */
    case 0xdf:	SET(3, pcpu->a);		break;	/* set 3,a */
    case 0xe0:	SET(4, pcpu->b);		break;	/* set 4,b */
    case 0xe1:	SET(4, pcpu->c);		break;	/* set 4,c */
    case 0xe2:	SET(4, pcpu->d);		break;	/* set 4,d */
    case 0xe3:	SET(4, pcpu->e);		break;	/* set 4,e */
    case 0xe4:	SET(4, pcpu->h);		break;	/* set 4,h */
    case 0xe5:	SET(4, pcpu->l);		break;	/* set 4,l */
    case 0xe6:	SETM(4);			break;	/* set 4,(hl) */
    case 0xe7:	SET(4, pcpu->a);		break;	/* set 4,a */
    case 0xe8:	SET(5, pcpu->b);		break;	/* set 5,b */
    case 0xe9:	SET(5, pcpu->c);		break;	/* set 5,c */
    case 0xea:	SET(5, pcpu->d);		break;	/* set 5,d */
    case 0xeb:	SET(5, pcpu->e);		break;	/* set 5,e */
    case 0xec:	SET(5, pcpu->h);		break;	/* set 5,h */
    case 0xed:	SET(5, pcpu->l);		break;	/* set 5,l */
    case 0xee:	SETM(5);			break;	/* set 5,(hl) */
    case 0xef:	SET(5, pcpu->a);		break;	/* set 5,a */
    case 0xf0:	SET(6, pcpu->b);		break;	/* set 6,b */
    case 0xf1:	SET(6, pcpu->c);		break;	/* set 6,c */
    case 0xf2:	SET(6, pcpu->d);		break;	/* set 6,d */
    case 0xf3:	SET(6, pcpu->e);		break;	/* set 6,e */
    case 0xf4:	SET(6, pcpu->h);		break;	/* set 6,h */
    case 0xf5:	SET(6, pcpu->l);		break;	/* set 6,l */
    case 0xf6:	SETM(6);			break;	/* set 6,(hl) */
    case 0xf7:	SET(6, pcpu->a);		break;	/* set 6,a */
    case 0xf8:	SET(7, pcpu->b);		break;	/* set 7,b */
    case 0xf9:	SET(7, pcpu->c);		break;	/* set 7,c */
    case 0xfa:	SET(7, pcpu->d);		break;	/* set 7,d */
    case 0xfb:	SET(7, pcpu->e);		break;	/* set 7,e */
    case 0xfc:	SET(7, pcpu->h);		break;	/* set 7,h */
    case 0xfd:	SET(7, pcpu->l);		break;	/* set 7,l */
    case 0xfe:	SETM(7);			break;	/* set 7,(hl) */
    case 0xff:	SET(7, pcpu->a);		break;	/* set 7,a */
    }
    break;						/* CB prefix */

  case 0xed:
    op = fetch(pcpu);
    pcpu->cycles += tstates_ed[op];

    switch (op) {

    case 0x40:						/* in b,(c) */
      pcpu->b = z80_in(BC);
      pcpu->f = FLAGS(pcpu->b) | (pcpu->f & CF);
      break;

    case 0x48:						/* in c,(c) */
      pcpu->c = z80_in(BC);
      pcpu->f = FLAGS(pcpu->c) | (pcpu->f & CF);
      break;

    case 0x50:						/* in d,(c) */
      pcpu->d = z80_in(BC);
      pcpu->f = FLAGS(pcpu->d) | (pcpu->f & CF);
      break;

    case 0x58:						/* in e,(c) */
      pcpu->e = z80_in(BC);
      pcpu->f = FLAGS(pcpu->e) | (pcpu->f & CF);
      break;

    case 0x60:						/* in h,(c) */
      pcpu->h = z80_in(BC);
      pcpu->f = FLAGS(pcpu->h) | (pcpu->f & CF);
      break;

    case 0x68:						/* in l,(c) */
      pcpu->l = z80_in(BC);
      pcpu->f = FLAGS(pcpu->l) | (pcpu->f & CF);
      break;

    case 0x70:						/* in f,(c) */
      pcpu->f = FLAGS(z80_in(BC)) | (pcpu->f & CF);
      break;

    case 0x78:						/* in a,(c) */
      pcpu->a = z80_in(BC);
      pcpu->f = FLAGS(pcpu->a) | (pcpu->f & CF);
      break;

    case 0x41:	z80_out(BC, pcpu->b);		break;	/* out (c),b */
    case 0x49:	z80_out(BC, pcpu->c);		break;	/* out (c),c */
    case 0x51:	z80_out(BC, pcpu->d);		break;	/* out (c),d */
    case 0x59:	z80_out(BC, pcpu->e);		break;	/* out (c),e */
    case 0x61:	z80_out(BC, pcpu->h);		break;	/* out (c),h */
    case 0x69:	z80_out(BC, pcpu->l);		break;	/* out (c),l */
    case 0x71:	z80_out(BC, 0);			break;	/* out (c),0 */
    case 0x79:	z80_out(BC, pcpu->a);		break;	/* out (c),a */

    case 0x42:	SBCHL(BC);			break;	/* sbc hl,bc */
    case 0x52:	SBCHL(DE);			break;	/* sbc hl,de */
    case 0x62:	SBCHL(HL);			break;	/* sbc hl,hl */
    case 0x72:	SBCHL(pcpu->sp);		break;	/* sbc hl,sp */

    case 0x4a:	ADCHL(BC);			break;	/* adc hl,bc */
    case 0x5a:	ADCHL(DE);			break;	/* adc hl,de */
    case 0x6a:	ADCHL(HL);			break;	/* adc hl,hl */
    case 0x7a:	ADCHL(pcpu->sp);		break;	/* adc hl,sp */

    case 0x43:						/* ld (nn),bc */
      tmp16 = z80_read(pcpu->pc++);
      tmp16 += z80_read(pcpu->pc++) << 8;
      z80_write(tmp16    , pcpu->c);
      z80_write(tmp16 + 1, pcpu->b);
      break;

    case 0x53:						/* ld (nn),de */
      tmp16 = z80_read(pcpu->pc++);
      tmp16 += z80_read(pcpu->pc++) << 8;
      z80_write(tmp16    , pcpu->e);
      z80_write(tmp16 + 1, pcpu->d);
      break;

    case 0x63:						/* ld (nn),hl */
      tmp16 = z80_read(pcpu->pc++);
      tmp16 += z80_read(pcpu->pc++) << 8;
      z80_write(tmp16    , pcpu->l);
      z80_write(tmp16 + 1, pcpu->h);
      break;

    case 0x73:						/* ld (nn),sp */
      tmp16 = z80_read(pcpu->pc++);
      tmp16 += z80_read(pcpu->pc++) << 8;
      z80_write(tmp16    , pcpu->sp & 0xff);
      z80_write(tmp16 + 1, pcpu->sp >> 8);
      break;

    case 0x44:	case 0x4c:				/* neg */
    case 0x54:	case 0x5c:
    case 0x64:	case 0x6c:
    case 0x74:	case 0x7c:
      tmp8 = 0x100 - pcpu->a;
      pcpu->f
	= (tmp8 & SF)
	| (tmp8 ? 0 : ZF)
	| (tmp8 & YF)
	| ((pcpu->a ^ tmp8) & HF)
	| (tmp8 & XF)
	| ((pcpu->a == 0x80) ? VF : 0)
	| NF
	| ((pcpu->a > 0) ? CF : 0);
      pcpu->a = tmp8;
      break;

    case 0x45:
    case 0x55:	case 0x5d:
    case 0x65:	case 0x6d:
    case 0x75:	case 0x7d:				/* retn */
    case 0x4d:						/* reti */
      pcpu->iff1 = pcpu->iff2;
      RET();
      break;

    case 0x46:	case 0x4e:
    case 0x66:	case 0x6e:				/* im 0 */
      pcpu->im = 0;
      break;
      
    case 0x56:	case 0x76:				/* im 1 */
      pcpu->im = 1;
      break;

    case 0x5e:	case 0x7e:				/* im 2 */
      pcpu->im = 2;
      break;

    case 0x47:						/* ld i,a */
      pcpu->i = pcpu->a;
      break;

    case 0x4f:						/* ld r,a */
      pcpu->r = pcpu->a;
      break;

    case 0x57:						/* ld a,i */
      pcpu->a = pcpu->i;
      pcpu->f
	= (pcpu->a & SF)
	| (pcpu->a ? 0 : ZF)
	| (pcpu->a & YF)
	| 0
	| (pcpu->a & XF)
	| (pcpu->iff2 ? PF : 0)
	| 0
	| (pcpu->f & CF);
      break;

   case 0x5f:						/* ld a,r */
      pcpu->a = pcpu->r;
      pcpu->f
	= (pcpu->a & SF)
	| (pcpu->a ? 0 : ZF)
	| (pcpu->a & YF)
	| 0
	| (pcpu->a & XF)
	| (pcpu->iff2 ? PF : 0)
	| 0
	| (pcpu->f & CF);
      break;

    case 0x4b:						/* ld bc,(nn) */
      tmp16 = z80_read(pcpu->pc++);
      tmp16 += z80_read(pcpu->pc++) << 8;
      pcpu->c = z80_read(tmp16);
      pcpu->b = z80_read(tmp16 + 1);
      break;

    case 0x5b:						/* ld de,(nn) */
      tmp16 = z80_read(pcpu->pc++);
      tmp16 += z80_read(pcpu->pc++) << 8;
      pcpu->e = z80_read(tmp16);
      pcpu->d = z80_read(tmp16 + 1);
      break;

    case 0x6b:						/* ld hl,(nn) */
      tmp16 = z80_read(pcpu->pc++);
      tmp16 += z80_read(pcpu->pc++) << 8;
      pcpu->l = z80_read(tmp16);
      pcpu->h = z80_read(tmp16 + 1);
      break;

    case 0x7b:						/* ld sp,(nn) */
      tmp16 = z80_read(pcpu->pc++);
      tmp16 += z80_read(pcpu->pc++) << 8;
      pcpu->sp = z80_read(tmp16);
      pcpu->sp += z80_read(tmp16 + 1) << 8;
      break;

    case 0x67:						/* rrd */
      tmp8 = z80_read(HL);
      z80_write(HL, (tmp8 >> 4) + (pcpu->a << 4));
      pcpu->a = (pcpu->a & 0xf0) + (tmp8 & 0x0f);
      pcpu->f = FLAGS(pcpu->a) | (pcpu->f & CF);
      break;

    case 0x6f:						/* rld */
      tmp8 = z80_read(HL);
      z80_write(HL, (tmp8 << 4) + (pcpu->a & 0x0f));
      pcpu->a = (pcpu->a & 0xf0) + (tmp8 >> 4);
      pcpu->f = FLAGS(pcpu->a) | (pcpu->f & CF);
      break;

    case 0x77:	case 0x7f:				/* nop */
      break;

    case 0xa0:	LDI();				break;	/* ldi */
    case 0xa1:	CPI();				break;	/* cpi */
    case 0xa2:	INI();				break;	/* ini */
    case 0xa3:	OUTI();				break;	/* outi */

    case 0xa8:	LDD();				break;	/* ldd */
    case 0xa9:	CPD();				break;	/* cpd */
    case 0xaa:	IND();				break;	/* ind */
    case 0xab:	OUTD();				break;	/* outd */

    case 0xb0:	LDI();	REPBC();		break;	/* ldir */
    case 0xb1:	CPI();	REPCP();		break;	/* cpir */
    case 0xb2:	INI();	REPB();			break;	/* inir */
    case 0xb3:	OUTI();	REPB();			break;	/* otir */

    case 0xb8:	LDD();	REPBC();		break;	/* lddr */
    case 0xb9:	CPD();	REPCP();		break;	/* cpdr */
    case 0xba:	IND();	REPB();			break;	/* indr */
    case 0xbb:	OUTD();	REPB();			break;	/* otdr */

    default:
      break;

    }
    break;						/* ED prefix */

  case 0xdd:
    op = fetch(pcpu);
    pcpu->cycles += tstates_dd[op];

    switch (op) {
    case 0x09:	ADDW(ixh, ixl, BC);		break;	/* add ix,bc */
    case 0x19:	ADDW(ixh, ixl, DE);		break;	/* add ix,bc */
    case 0x29:	ADDW(ixh, ixl, IX);		break;	/* add ix,ix */
    case 0x39:	ADDW(ixh, ixl, pcpu->sp);	break;	/* add ix,sp */
      
    case 0x21:						/* ld ix,nn */
      pcpu->ixl = z80_read(pcpu->pc++);
      pcpu->ixh = z80_read(pcpu->pc++);
      break;

    case 0x22:						/* ld (nn),ix */
      tmp16 = z80_read(pcpu->pc++);
      tmp16 += z80_read(pcpu->pc++) << 8;
      z80_write(tmp16,     pcpu->ixl);
      z80_write(tmp16 + 1, pcpu->ixh);
      break;

    case 0x23:	INCW(ixh, ixl);			break;	/* inc ix */
    case 0x2b:	DECW(ixh, ixl);			break;	/* dec ix */

    case 0x24:	INC(pcpu->ixh);			break;	/* inc ixh */
    case 0x2c:	INC(pcpu->ixl);			break;	/* inc ixl */

    case 0x25:	DEC(pcpu->ixh);			break;	/* dec ixh */
    case 0x2d:	DEC(pcpu->ixl);			break;	/* dec ixl */


    case 0x26:	pcpu->ixh = z80_read(pcpu->pc++);	break;	/* ld ixh,n */
    case 0x2e:	pcpu->ixl = z80_read(pcpu->pc++);	break;	/* ld ixl,n */

    case 0x2a:						/* ld ix,(nn) */
      tmp16 = z80_read(pcpu->pc++);
      tmp16 += z80_read(pcpu->pc++) << 8;
      pcpu->ixl = z80_read(tmp16);
      pcpu->ixh = z80_read(tmp16 + 1);
      break;

    case 0x34:						/* inc (ix+d) */
      tmp16 = IXD;
      tmp8 = z80_read(tmp16);
      INC(tmp8);
      z80_write(tmp16, tmp8);
      break;

    case 0x35:						/* dec (ix+d) */
      tmp16 = IXD;
      tmp8 = z80_read(tmp16);
      DEC(tmp8);
      z80_write(tmp16, tmp8);
      break;

    case 0x36:						/* ld (ix+d),n */
      tmp16 = IXD;
      z80_write(tmp16, z80_read(pcpu->pc++));
      break;

    case 0x44:	pcpu->b = pcpu->ixh;		break;	/* ld b,ixh */
    case 0x45:	pcpu->b = pcpu->ixl;		break;	/* ld b,ixl */
    case 0x46:
      tmp16 = IXD;
      pcpu->b = z80_read(tmp16);
      pcpu->internal = tmp16 >> 8;		break;	/* ld b,(ix+d) */
    case 0x4c:	pcpu->c = pcpu->ixh;		break;	/* ld c,ixh */
    case 0x4d:	pcpu->c = pcpu->ixl;		break;	/* ld c,ixl */
    case 0x4e:
      tmp16 = IXD;
      pcpu->c = z80_read(tmp16);
      pcpu->internal = tmp16 >> 8;		break;	/* ld c,(ix+d) */
    case 0x54:	pcpu->d = pcpu->ixh;		break;	/* ld d,ixh */
    case 0x55:	pcpu->d = pcpu->ixl;		break;	/* ld d,ixl */
    case 0x56:
      tmp16 = IXD;
      pcpu->d = z80_read(tmp16);
      pcpu->internal = tmp16 >> 8; 		break;	/* ld d,(ix+d) */
    case 0x5c:	pcpu->e = pcpu->ixh;		break;	/* ld e,ixh */
    case 0x5d:	pcpu->e = pcpu->ixl;		break;	/* ld e,ixl */
    case 0x5e:
      tmp16 = IXD;
      pcpu->e = z80_read(tmp16);
      pcpu->internal = tmp16 >> 8; 		break;	/* ld e,(ix+d) */

    case 0x60:	pcpu->ixh = pcpu->b;		break;	/* ld ixh,b */
    case 0x61:	pcpu->ixh = pcpu->c;		break;	/* ld ixh,c */
    case 0x62:	pcpu->ixh = pcpu->d;		break;	/* ld ixh,d */
    case 0x63:	pcpu->ixh = pcpu->e;		break;	/* ld ixh,e */
    case 0x64:	pcpu->ixh = pcpu->ixh;		break;	/* ld ixh,ixh */
    case 0x65:	pcpu->ixh = pcpu->ixl;		break;	/* ld ixh,ixl */
    case 0x66:
      tmp16 = IXD;
      pcpu->h = z80_read(tmp16);
      pcpu->internal = tmp16 >> 8; 		break;	/* ld h,(ix+d) */
    case 0x67:	pcpu->ixh = pcpu->a;		break;	/* ld ixh,a */

    case 0x68:	pcpu->ixl = pcpu->b;		break;	/* ld ixl,b */
    case 0x69:	pcpu->ixl = pcpu->c;		break;	/* ld ixl,c */
    case 0x6a:	pcpu->ixl = pcpu->d;		break;	/* ld ixl,d */
    case 0x6b:	pcpu->ixl = pcpu->e;		break;	/* ld ixl,e */
    case 0x6c:	pcpu->ixl = pcpu->ixh;		break;	/* ld ixl,ixh */
    case 0x6d:	pcpu->ixl = pcpu->ixl;		break;	/* ld ixl,ixl */
    case 0x6e:
      tmp16 = IXD;
      pcpu->l = z80_read(tmp16);
      pcpu->internal = tmp16 >> 8; 		break;	/* ld l,(ix+d) */
    case 0x6f:	pcpu->ixl = pcpu->a;		break;	/* ld ixl,a */

    case 0x70:	z80_write(IXD, pcpu->b);	break;	/* ld (ix+d),b */
    case 0x71:	z80_write(IXD, pcpu->c);	break;	/* ld (ix+d),c */
    case 0x72:	z80_write(IXD, pcpu->d);	break;	/* ld (ix+d),d */
    case 0x73:	z80_write(IXD, pcpu->e);	break;	/* ld (ix+d),e */
    case 0x74:	z80_write(IXD, pcpu->h);	break;	/* ld (ix+d),h */
    case 0x75:	z80_write(IXD, pcpu->l);	break;	/* ld (ix+d),l */
    case 0x77:	z80_write(IXD, pcpu->a);	break;	/* ld (ix+d),a */

    case 0x7c:	pcpu->a = pcpu->ixh;		break;	/* ld a,ixh */
    case 0x7d:	pcpu->a = pcpu->ixl;		break;	/* ld a,ixl */
    case 0x7e:
      tmp16 = IXD;
      pcpu->a = z80_read(tmp16);
      pcpu->internal = tmp16 >> 8; 		break;	/* ld a,(ix+d) */

    case 0x84:	ADD(pcpu->ixh);			break;	/* add a,ixh */
    case 0x85:	ADD(pcpu->ixl);			break;	/* add a,ixl */
    case 0x86:	ADD(z80_read(IXD));		break;	/* add a,(ix+d) */

    case 0x8c:	ADC(pcpu->ixh);			break;	/* adc a,ixh */
    case 0x8d:	ADC(pcpu->ixl);			break;	/* adc a,ixl */
    case 0x8e:	ADC(z80_read(IXD));		break;	/* adc a,(ix+d) */

    case 0x94:	SUB(pcpu->ixh);			break;	/* sub ixh */
    case 0x95:	SUB(pcpu->ixl);			break;	/* sub ixl */
    case 0x96:	SUB(z80_read(IXD));		break;	/* sub (ix+d) */

    case 0x9c:	SBC(pcpu->ixh);			break;	/* sbc a,ixh */
    case 0x9d:	SBC(pcpu->ixl);			break;	/* sbc a,ixl */
    case 0x9e:	SBC(z80_read(IXD));		break;	/* sbc (ix+d) */

    case 0xa4:	AND(pcpu->ixh);			break;	/* and ixh */
    case 0xa5:	AND(pcpu->ixl);			break;	/* and ixl */
    case 0xa6:	AND(z80_read(IXD));		break;	/* and (ix+d) */

    case 0xac:	XOR(pcpu->ixh);			break;	/* xor ixh */
    case 0xad:	XOR(pcpu->ixl);			break;	/* xor ixl */
    case 0xae:	XOR(z80_read(IXD));		break;	/* xor (ix+d) */

    case 0xb4:	OR(pcpu->ixh);			break;	/* or ixh */
    case 0xb5:	OR(pcpu->ixl);			break;	/* or ixl */
    case 0xb6:	OR(z80_read(IXD));		break;	/* or (ix+d) */

    case 0xbc:	CP(pcpu->ixh);			break;	/* cp ixh */
    case 0xbd:	CP(pcpu->ixl);			break;	/* cp ixl */
    case 0xbe:	CP(z80_read(IXD));		break;	/* cp (ix+d) */

    case 0xe1:	POP(ixh, ixl);			break;	/* pop ix */

    case 0xe3:						/* ex (sp),ix */
      tmp8 = z80_read(pcpu->sp);
      z80_write(pcpu->sp, pcpu->ixl);
      pcpu->ixl = tmp8;
      tmp8 = z80_read(pcpu->sp + 1);
      z80_write(pcpu->sp + 1, pcpu->ixh);
      pcpu->ixh = tmp8;
      break;

    case 0xe5:						/* push ix */
      PUSH(ixh, ixl);
      break;

    case 0xe9:						/* jp (ix) */
      pcpu->pc = IX;
      break;

    case 0xed:						/* ED prefix */
      exec_code(pcpu, 0xed);
      break;

    case 0xf9:						/* ld sp,ix */
      pcpu->sp = IX;
      break;

    case 0xcb:
      tmp16 = IXD;
      op = z80_read(pcpu->pc++);
      pcpu->cycles += tstates_ddcb[op];

      switch (op) {
      case 0x00:	IXY(RLC, pcpu->b);	break;	/* rlc (ix+d),b */
      case 0x01:	IXY(RLC, pcpu->c);	break;	/* rlc (ix+d),c */
      case 0x02:	IXY(RLC, pcpu->d);	break;	/* rlc (ix+d),d */
      case 0x03:	IXY(RLC, pcpu->e);	break;	/* rlc (ix+d),e */
      case 0x04:	IXY(RLC, pcpu->h);	break;	/* rlc (ix+d),h */
      case 0x05:	IXY(RLC, pcpu->l);	break;	/* rlc (ix+d),l */
      case 0x06:	IXY(RLC, tmp8);		break;	/* rlc (ix+d) */
      case 0x07:	IXY(RLC, pcpu->a);	break;	/* rlc (ix+d),a */

      case 0x08:	IXY(RRC, pcpu->b);	break;	/* rrc (ix+d),b */
      case 0x09:	IXY(RRC, pcpu->c);	break;	/* rrc (ix+d),c */
      case 0x0a:	IXY(RRC, pcpu->d);	break;	/* rrc (ix+d),d */
      case 0x0b:	IXY(RRC, pcpu->e);	break;	/* rrc (ix+d),e */
      case 0x0c:	IXY(RRC, pcpu->h);	break;	/* rrc (ix+d),h */
      case 0x0d:	IXY(RRC, pcpu->l);	break;	/* rrc (ix+d),l */
      case 0x0e:	IXY(RRC, tmp8);		break;	/* rrc (ix+d) */
      case 0x0f:	IXY(RRC, pcpu->a);	break;	/* rrc (ix+d),a */

      case 0x10:	IXY(RL, pcpu->b);	break;	/* rl (ix+d),b */
      case 0x11:	IXY(RL, pcpu->c);	break;	/* rl (ix+d),c */
      case 0x12:	IXY(RL, pcpu->d);	break;	/* rl (ix+d),d */
      case 0x13:	IXY(RL, pcpu->e);	break;	/* rl (ix+d),e */
      case 0x14:	IXY(RL, pcpu->h);	break;	/* rl (ix+d),h */
      case 0x15:	IXY(RL, pcpu->l);	break;	/* rl (ix+d),l */
      case 0x16:	IXY(RL, tmp8);		break;	/* rl (ix+d) */
      case 0x17:	IXY(RL, pcpu->a);	break;	/* rl (ix+d),a */

      case 0x18:	IXY(RR, pcpu->b);	break;	/* rr (ix+d),b */
      case 0x19:	IXY(RR, pcpu->c);	break;	/* rr (ix+d),c */
      case 0x1a:	IXY(RR, pcpu->d);	break;	/* rr (ix+d),d */
      case 0x1b:	IXY(RR, pcpu->e);	break;	/* rr (ix+d),e */
      case 0x1c:	IXY(RR, pcpu->h);	break;	/* rr (ix+d),h */
      case 0x1d:	IXY(RR, pcpu->l);	break;	/* rr (ix+d),l */
      case 0x1e:	IXY(RR, tmp8);		break;	/* rr (ix+d) */
      case 0x1f:	IXY(RR, pcpu->a);	break;	/* rr (ix+d),a */

      case 0x20:	IXY(SLA, pcpu->b);	break;	/* sla (ix+d),b */
      case 0x21:	IXY(SLA, pcpu->c);	break;	/* sla (ix+d),c */
      case 0x22:	IXY(SLA, pcpu->d);	break;	/* sla (ix+d),d */
      case 0x23:	IXY(SLA, pcpu->e);	break;	/* sla (ix+d),e */
      case 0x24:	IXY(SLA, pcpu->h);	break;	/* sla (ix+d),h */
      case 0x25:	IXY(SLA, pcpu->l);	break;	/* sla (ix+d),l */
      case 0x26:	IXY(SLA, tmp8);		break;	/* sla (ix+d) */
      case 0x27:	IXY(SLA, pcpu->a);	break;	/* sla (ix+d),a */

      case 0x28:	IXY(SRA, pcpu->b);	break;	/* sra (ix+d),b */
      case 0x29:	IXY(SRA, pcpu->c);	break;	/* sra (ix+d),c */
      case 0x2a:	IXY(SRA, pcpu->d);	break;	/* sra (ix+d),d */
      case 0x2b:	IXY(SRA, pcpu->e);	break;	/* sra (ix+d),e */
      case 0x2c:	IXY(SRA, pcpu->h);	break;	/* sra (ix+d),h */
      case 0x2d:	IXY(SRA, pcpu->l);	break;	/* sra (ix+d),l */
      case 0x2e:	IXY(SRA, tmp8);		break;	/* sra (ix+d) */
      case 0x2f:	IXY(SRA, pcpu->a);	break;	/* sra (ix+d),a */

      case 0x30:	IXY(SLL, pcpu->b);	break;	/* sll (ix+d),b */
      case 0x31:	IXY(SLL, pcpu->c);	break;	/* sll (ix+d),c */
      case 0x32:	IXY(SLL, pcpu->d);	break;	/* sll (ix+d),d */
      case 0x33:	IXY(SLL, pcpu->e);	break;	/* sll (ix+d),e */
      case 0x34:	IXY(SLL, pcpu->h);	break;	/* sll (ix+d),h */
      case 0x35:	IXY(SLL, pcpu->l);	break;	/* sll (ix+d),l */
      case 0x36:	IXY(SLL, tmp8);		break;	/* sll (ix+d) */
      case 0x37:	IXY(SLL, pcpu->a);	break;	/* sll (ix+d),a */

      case 0x38:	IXY(SRL, pcpu->b);	break;	/* srl (ix+d),b */
      case 0x39:	IXY(SRL, pcpu->c);	break;	/* srl (ix+d),c */
      case 0x3a:	IXY(SRL, pcpu->d);	break;	/* srl (ix+d),d */
      case 0x3b:	IXY(SRL, pcpu->e);	break;	/* srl (ix+d),e */
      case 0x3c:	IXY(SRL, pcpu->h);	break;	/* srl (ix+d),h */
      case 0x3d:	IXY(SRL, pcpu->l);	break;	/* srl (ix+d),l */
      case 0x3e:	IXY(SRL, tmp8);		break;	/* srl (ix+d) */
      case 0x3f:	IXY(SRL, pcpu->a);	break;	/* srl (ix+d),a */

      case 0x40:	case 0x41:	case 0x42:	case 0x43:
      case 0x44:	case 0x45:	case 0x46:	case 0x47:
      case 0x48:	case 0x49:	case 0x4a:	case 0x4b:
      case 0x4c:	case 0x4d:	case 0x4e:	case 0x4f:
      case 0x50:	case 0x51:	case 0x52:	case 0x53:
      case 0x54:	case 0x55:	case 0x56:	case 0x57:
      case 0x58:	case 0x59:	case 0x5a:	case 0x5b:
      case 0x5c:	case 0x5d:	case 0x5e:	case 0x5f:
      case 0x60:	case 0x61:	case 0x62:	case 0x63:
      case 0x64:	case 0x65:	case 0x66:	case 0x67:
      case 0x68:	case 0x69:	case 0x6a:	case 0x6b:
      case 0x6c:	case 0x6d:	case 0x6e:	case 0x6f:
      case 0x70:	case 0x71:	case 0x72:	case 0x73:
      case 0x74:	case 0x75:	case 0x76:	case 0x77:
      case 0x78:	case 0x79:	case 0x7a:	case 0x7b:
      case 0x7c:	case 0x7d:	case 0x7e:	case 0x7f:
	BITIXY((op >> 3) & 0x07, z80_read(tmp16));	/* bit n,(ix+d) */
	break;

      case 0x80:	IXY2(RES, 0, pcpu->b);	break;	/* res 0,(ix+d),b */
      case 0x81:	IXY2(RES, 0, pcpu->c);	break;	/* res 0,(ix+d),c */
      case 0x82:	IXY2(RES, 0, pcpu->d);	break;	/* res 0,(ix+d),d */
      case 0x83:	IXY2(RES, 0, pcpu->e);	break;	/* res 0,(ix+d),e */
      case 0x84:	IXY2(RES, 0, pcpu->h);	break;	/* res 0,(ix+d),h */
      case 0x85:	IXY2(RES, 0, pcpu->l);	break;	/* res 0,(ix+d),l */
      case 0x86:	IXY2(RES, 0, tmp8);	break;	/* res 0,(ix+d) */
      case 0x87:	IXY2(RES, 0, pcpu->a);	break;	/* res 0,(ix+d),a */
      case 0x88:	IXY2(RES, 1, pcpu->b);	break;	/* res 1,(ix+d),b */
      case 0x89:	IXY2(RES, 1, pcpu->c);	break;	/* res 1,(ix+d),c */
      case 0x8a:	IXY2(RES, 1, pcpu->d);	break;	/* res 1,(ix+d),d */
      case 0x8b:	IXY2(RES, 1, pcpu->e);	break;	/* res 1,(ix+d),e */
      case 0x8c:	IXY2(RES, 1, pcpu->h);	break;	/* res 1,(ix+d),h */
      case 0x8d:	IXY2(RES, 1, pcpu->l);	break;	/* res 1,(ix+d),l */
      case 0x8e:	IXY2(RES, 1, tmp8);	break;	/* res 1,(ix+d) */
      case 0x8f:	IXY2(RES, 1, pcpu->a);	break;	/* res 1,(ix+d),a */
      case 0x90:	IXY2(RES, 2, pcpu->b);	break;	/* res 2,(ix+d),b */
      case 0x91:	IXY2(RES, 2, pcpu->c);	break;	/* res 2,(ix+d),c */
      case 0x92:	IXY2(RES, 2, pcpu->d);	break;	/* res 2,(ix+d),d */
      case 0x93:	IXY2(RES, 2, pcpu->e);	break;	/* res 2,(ix+d),e */
      case 0x94:	IXY2(RES, 2, pcpu->h);	break;	/* res 2,(ix+d),h */
      case 0x95:	IXY2(RES, 2, pcpu->l);	break;	/* res 2,(ix+d),l */
      case 0x96:	IXY2(RES, 2, tmp8);	break;	/* res 2,(ix+d) */
      case 0x97:	IXY2(RES, 2, pcpu->a);	break;	/* res 2,(ix+d),a */
      case 0x98:	IXY2(RES, 3, pcpu->b);	break;	/* res 3,(ix+d),b */
      case 0x99:	IXY2(RES, 3, pcpu->c);	break;	/* res 3,(ix+d),c */
      case 0x9a:	IXY2(RES, 3, pcpu->d);	break;	/* res 3,(ix+d),d */
      case 0x9b:	IXY2(RES, 3, pcpu->e);	break;	/* res 3,(ix+d),e */
      case 0x9c:	IXY2(RES, 3, pcpu->h);	break;	/* res 3,(ix+d),h */
      case 0x9d:	IXY2(RES, 3, pcpu->l);	break;	/* res 3,(ix+d),l */
      case 0x9e:	IXY2(RES, 3, tmp8);	break;	/* res 3,(ix+d) */
      case 0x9f:	IXY2(RES, 3, pcpu->a);	break;	/* res 3,(ix+d),a */
      case 0xa0:	IXY2(RES, 4, pcpu->b);	break;	/* res 4,(ix+d),b */
      case 0xa1:	IXY2(RES, 4, pcpu->c);	break;	/* res 4,(ix+d),c */
      case 0xa2:	IXY2(RES, 4, pcpu->d);	break;	/* res 4,(ix+d),d */
      case 0xa3:	IXY2(RES, 4, pcpu->e);	break;	/* res 4,(ix+d),e */
      case 0xa4:	IXY2(RES, 4, pcpu->h);	break;	/* res 4,(ix+d),h */
      case 0xa5:	IXY2(RES, 4, pcpu->l);	break;	/* res 4,(ix+d),l */
      case 0xa6:	IXY2(RES, 4, tmp8);	break;	/* res 4,(ix+d) */
      case 0xa7:	IXY2(RES, 4, pcpu->a);	break;	/* res 4,(ix+d),a */
      case 0xa8:	IXY2(RES, 5, pcpu->b);	break;	/* res 5,(ix+d),b */
      case 0xa9:	IXY2(RES, 5, pcpu->c);	break;	/* res 5,(ix+d),c */
      case 0xaa:	IXY2(RES, 5, pcpu->d);	break;	/* res 5,(ix+d),d */
      case 0xab:	IXY2(RES, 5, pcpu->e);	break;	/* res 5,(ix+d),e */
      case 0xac:	IXY2(RES, 5, pcpu->h);	break;	/* res 5,(ix+d),h */
      case 0xad:	IXY2(RES, 5, pcpu->l);	break;	/* res 5,(ix+d),l */
      case 0xae:	IXY2(RES, 5, tmp8);	break;	/* res 5,(ix+d) */
      case 0xaf:	IXY2(RES, 5, pcpu->a);	break;	/* res 5,(ix+d),a */
      case 0xb0:	IXY2(RES, 6, pcpu->b);	break;	/* res 6,(ix+d),b */
      case 0xb1:	IXY2(RES, 6, pcpu->c);	break;	/* res 6,(ix+d),c */
      case 0xb2:	IXY2(RES, 6, pcpu->d);	break;	/* res 6,(ix+d),d */
      case 0xb3:	IXY2(RES, 6, pcpu->e);	break;	/* res 6,(ix+d),e */
      case 0xb4:	IXY2(RES, 6, pcpu->h);	break;	/* res 6,(ix+d),h */
      case 0xb5:	IXY2(RES, 6, pcpu->l);	break;	/* res 6,(ix+d),l */
      case 0xb6:	IXY2(RES, 6, tmp8);	break;	/* res 6,(ix+d) */
      case 0xb7:	IXY2(RES, 6, pcpu->a);	break;	/* res 6,(ix+d),a */
      case 0xb8:	IXY2(RES, 7, pcpu->b);	break;	/* res 7,(ix+d),b */
      case 0xb9:	IXY2(RES, 7, pcpu->c);	break;	/* res 7,(ix+d),c */
      case 0xba:	IXY2(RES, 7, pcpu->d);	break;	/* res 7,(ix+d),d */
      case 0xbb:	IXY2(RES, 7, pcpu->e);	break;	/* res 7,(ix+d),e */
      case 0xbc:	IXY2(RES, 7, pcpu->h);	break;	/* res 7,(ix+d),h */
      case 0xbd:	IXY2(RES, 7, pcpu->l);	break;	/* res 7,(ix+d),l */
      case 0xbe:	IXY2(RES, 7, tmp8);	break;	/* res 7,(ix+d) */
      case 0xbf:	IXY2(RES, 7, pcpu->a);	break;	/* res 7,(ix+d),a */
      case 0xc0:	IXY2(SET, 0, pcpu->b);	break;	/* res 0,(ix+d),b */
      case 0xc1:	IXY2(SET, 0, pcpu->c);	break;	/* res 0,(ix+d),c */
      case 0xc2:	IXY2(SET, 0, pcpu->d);	break;	/* res 0,(ix+d),d */
      case 0xc3:	IXY2(SET, 0, pcpu->e);	break;	/* res 0,(ix+d),e */
      case 0xc4:	IXY2(SET, 0, pcpu->h);	break;	/* res 0,(ix+d),h */
      case 0xc5:	IXY2(SET, 0, pcpu->l);	break;	/* res 0,(ix+d),l */
      case 0xc6:	IXY2(SET, 0, tmp8);	break;	/* res 0,(ix+d) */
      case 0xc7:	IXY2(SET, 0, pcpu->a);	break;	/* res 0,(ix+d),a */
      case 0xc8:	IXY2(SET, 1, pcpu->b);	break;	/* res 1,(ix+d),b */
      case 0xc9:	IXY2(SET, 1, pcpu->c);	break;	/* res 1,(ix+d),c */
      case 0xca:	IXY2(SET, 1, pcpu->d);	break;	/* res 1,(ix+d),d */
      case 0xcb:	IXY2(SET, 1, pcpu->e);	break;	/* res 1,(ix+d),e */
      case 0xcc:	IXY2(SET, 1, pcpu->h);	break;	/* res 1,(ix+d),h */
      case 0xcd:	IXY2(SET, 1, pcpu->l);	break;	/* res 1,(ix+d),l */
      case 0xce:	IXY2(SET, 1, tmp8);	break;	/* res 1,(ix+d) */
      case 0xcf:	IXY2(SET, 1, pcpu->a);	break;	/* res 1,(ix+d),a */
      case 0xd0:	IXY2(SET, 2, pcpu->b);	break;	/* res 2,(ix+d),b */
      case 0xd1:	IXY2(SET, 2, pcpu->c);	break;	/* res 2,(ix+d),c */
      case 0xd2:	IXY2(SET, 2, pcpu->d);	break;	/* res 2,(ix+d),d */
      case 0xd3:	IXY2(SET, 2, pcpu->e);	break;	/* res 2,(ix+d),e */
      case 0xd4:	IXY2(SET, 2, pcpu->h);	break;	/* res 2,(ix+d),h */
      case 0xd5:	IXY2(SET, 2, pcpu->l);	break;	/* res 2,(ix+d),l */
      case 0xd6:	IXY2(SET, 2, tmp8);	break;	/* res 2,(ix+d) */
      case 0xd7:	IXY2(SET, 2, pcpu->a);	break;	/* res 2,(ix+d),a */
      case 0xd8:	IXY2(SET, 3, pcpu->b);	break;	/* res 3,(ix+d),b */
      case 0xd9:	IXY2(SET, 3, pcpu->c);	break;	/* res 3,(ix+d),c */
      case 0xda:	IXY2(SET, 3, pcpu->d);	break;	/* res 3,(ix+d),d */
      case 0xdb:	IXY2(SET, 3, pcpu->e);	break;	/* res 3,(ix+d),e */
      case 0xdc:	IXY2(SET, 3, pcpu->h);	break;	/* res 3,(ix+d),h */
      case 0xdd:	IXY2(SET, 3, pcpu->l);	break;	/* res 3,(ix+d),l */
      case 0xde:	IXY2(SET, 3, tmp8);	break;	/* res 3,(ix+d) */
      case 0xdf:	IXY2(SET, 3, pcpu->a);	break;	/* res 3,(ix+d),a */
      case 0xe0:	IXY2(SET, 4, pcpu->b);	break;	/* res 4,(ix+d),b */
      case 0xe1:	IXY2(SET, 4, pcpu->c);	break;	/* res 4,(ix+d),c */
      case 0xe2:	IXY2(SET, 4, pcpu->d);	break;	/* res 4,(ix+d),d */
      case 0xe3:	IXY2(SET, 4, pcpu->e);	break;	/* res 4,(ix+d),e */
      case 0xe4:	IXY2(SET, 4, pcpu->h);	break;	/* res 4,(ix+d),h */
      case 0xe5:	IXY2(SET, 4, pcpu->l);	break;	/* res 4,(ix+d),l */
      case 0xe6:	IXY2(SET, 4, tmp8);	break;	/* res 4,(ix+d) */
      case 0xe7:	IXY2(SET, 4, pcpu->a);	break;	/* res 4,(ix+d),a */
      case 0xe8:	IXY2(SET, 5, pcpu->b);	break;	/* res 5,(ix+d),b */
      case 0xe9:	IXY2(SET, 5, pcpu->c);	break;	/* res 5,(ix+d),c */
      case 0xea:	IXY2(SET, 5, pcpu->d);	break;	/* res 5,(ix+d),d */
      case 0xeb:	IXY2(SET, 5, pcpu->e);	break;	/* res 5,(ix+d),e */
      case 0xec:	IXY2(SET, 5, pcpu->h);	break;	/* res 5,(ix+d),h */
      case 0xed:	IXY2(SET, 5, pcpu->l);	break;	/* res 5,(ix+d),l */
      case 0xee:	IXY2(SET, 5, tmp8);	break;	/* res 5,(ix+d) */
      case 0xef:	IXY2(SET, 5, pcpu->a);	break;	/* res 5,(ix+d),a */
      case 0xf0:	IXY2(SET, 6, pcpu->b);	break;	/* res 6,(ix+d),b */
      case 0xf1:	IXY2(SET, 6, pcpu->c);	break;	/* res 6,(ix+d),c */
      case 0xf2:	IXY2(SET, 6, pcpu->d);	break;	/* res 6,(ix+d),d */
      case 0xf3:	IXY2(SET, 6, pcpu->e);	break;	/* res 6,(ix+d),e */
      case 0xf4:	IXY2(SET, 6, pcpu->h);	break;	/* res 6,(ix+d),h */
      case 0xf5:	IXY2(SET, 6, pcpu->l);	break;	/* res 6,(ix+d),l */
      case 0xf6:	IXY2(SET, 6, tmp8);	break;	/* res 6,(ix+d) */
      case 0xf7:	IXY2(SET, 6, pcpu->a);	break;	/* res 6,(ix+d),a */
      case 0xf8:	IXY2(SET, 7, pcpu->b);	break;	/* res 7,(ix+d),b */
      case 0xf9:	IXY2(SET, 7, pcpu->c);	break;	/* res 7,(ix+d),c */
      case 0xfa:	IXY2(SET, 7, pcpu->d);	break;	/* res 7,(ix+d),d */
      case 0xfb:	IXY2(SET, 7, pcpu->e);	break;	/* res 7,(ix+d),e */
      case 0xfc:	IXY2(SET, 7, pcpu->h);	break;	/* res 7,(ix+d),h */
      case 0xfd:	IXY2(SET, 7, pcpu->l);	break;	/* res 7,(ix+d),l */
      case 0xfe:	IXY2(SET, 7, tmp8);	break;	/* res 7,(ix+d) */
      case 0xff:	IXY2(SET, 7, pcpu->a);	break;	/* res 7,(ix+d),a */
      }

      break;						/* DDCB prefix */

    default:
      exec_code(pcpu, op);
      break;
    }
    break;						/* DD prefix */

  case 0xfd:
    op = fetch(pcpu);
    pcpu->cycles += tstates_dd[op];

    switch (op) {
    case 0x09:	ADDW(iyh, iyl, BC);		break;	/* add iy,bc */
    case 0x19:	ADDW(iyh, iyl, DE);		break;	/* add iy,bc */
    case 0x29:	ADDW(iyh, iyl, IY);		break;	/* add iy,iy */
    case 0x39:	ADDW(iyh, iyl, pcpu->sp);	break;	/* add iy,sp */
      
    case 0x21:						/* ld iy,nn */
      pcpu->iyl = z80_read(pcpu->pc++);
      pcpu->iyh = z80_read(pcpu->pc++);
      break;

    case 0x22:						/* ld (nn),iy */
      tmp16 = z80_read(pcpu->pc++);
      tmp16 += z80_read(pcpu->pc++) << 8;
      z80_write(tmp16,     pcpu->iyl);
      z80_write(tmp16 + 1, pcpu->iyh);
      break;

    case 0x23:	INCW(iyh, iyl);			break;	/* inc iy */
    case 0x2b:	DECW(iyh, iyl);			break;	/* dec iy */

    case 0x24:	INC(pcpu->iyh);			break;	/* inc iyh */
    case 0x2c:	INC(pcpu->iyl);			break;	/* inc iyl */

    case 0x25:	DEC(pcpu->iyh);			break;	/* dec iyh */
    case 0x2d:	DEC(pcpu->iyl);			break;	/* dec iyl */

    case 0x26:	pcpu->iyh = z80_read(pcpu->pc++);	break;	/* ld iyh,n */
    case 0x2e:	pcpu->iyl = z80_read(pcpu->pc++);	break;	/* ld iyl,n */

    case 0x2a:						/* ld iy,(nn) */
      tmp16 = z80_read(pcpu->pc++);
      tmp16 += z80_read(pcpu->pc++) << 8;
      pcpu->iyl = z80_read(tmp16);
      pcpu->iyh = z80_read(tmp16 + 1);
      break;

    case 0x34:						/* inc (iy+d) */
      tmp16 = IYD;
      tmp8 = z80_read(tmp16);
      INC(tmp8);
      z80_write(tmp16, tmp8);
      break;

    case 0x35:						/* dec (iy+d) */
      tmp16 = IYD;
      tmp8 = z80_read(tmp16);
      DEC(tmp8);
      z80_write(tmp16, tmp8);
      break;

    case 0x36:						/* ld (iy+d),n */
      tmp16 = IYD;
      z80_write(tmp16, z80_read(pcpu->pc++));
      break;

    case 0x44:	pcpu->b = pcpu->iyh;		break;	/* ld b,iyh */
    case 0x45:	pcpu->b = pcpu->iyl;		break;	/* ld b,iyl */
    case 0x46:
      tmp16 = IYD;
      pcpu->b = z80_read(tmp16);
      pcpu->internal = tmp16 >> 8;		break;	/* ld b,(iy+d) */
    case 0x4c:	pcpu->c = pcpu->iyh;		break;	/* ld c,iyh */
    case 0x4d:	pcpu->c = pcpu->iyl;		break;	/* ld c,iyl */
    case 0x4e:
      tmp16 = IYD;
      pcpu->c = z80_read(tmp16);
      pcpu->internal = tmp16 >> 8;		break;	/* ld c,(iy+d) */
    case 0x54:	pcpu->d = pcpu->iyh;		break;	/* ld d,iyh */
    case 0x55:	pcpu->d = pcpu->iyl;		break;	/* ld d,iyl */
    case 0x56:
      tmp16 = IYD;
      pcpu->d = z80_read(tmp16);
      pcpu->internal = tmp16 >> 8;		break;	/* ld d,(iy+d) */
    case 0x5c:	pcpu->e = pcpu->iyh;		break;	/* ld e,iyh */
    case 0x5d:	pcpu->e = pcpu->iyl;		break;	/* ld e,iyl */
    case 0x5e:
      tmp16 = IYD;
      pcpu->e = z80_read(tmp16);
      pcpu->internal = tmp16 >> 8;		break;	/* ld e,(iy+d) */

    case 0x60:	pcpu->iyh = pcpu->b;		break;	/* ld iyh,b */
    case 0x61:	pcpu->iyh = pcpu->c;		break;	/* ld iyh,c */
    case 0x62:	pcpu->iyh = pcpu->d;		break;	/* ld iyh,d */
    case 0x63:	pcpu->iyh = pcpu->e;		break;	/* ld iyh,e */
    case 0x64:	pcpu->iyh = pcpu->iyh;		break;	/* ld iyh,iyh */
    case 0x65:	pcpu->iyh = pcpu->iyl;		break;	/* ld iyh,iyl */
    case 0x66:
      tmp16 = IYD;
      pcpu->h = z80_read(tmp16);
      pcpu->internal = tmp16 >> 8;		break;	/* ld h,(iy+d) */
    case 0x67:	pcpu->iyh = pcpu->a;		break;	/* ld iyh,a */

    case 0x68:	pcpu->iyl = pcpu->b;		break;	/* ld iyl,b */
    case 0x69:	pcpu->iyl = pcpu->c;		break;	/* ld iyl,c */
    case 0x6a:	pcpu->iyl = pcpu->d;		break;	/* ld iyl,d */
    case 0x6b:	pcpu->iyl = pcpu->e;		break;	/* ld iyl,e */
    case 0x6c:	pcpu->iyl = pcpu->iyh;		break;	/* ld iyl,iyh */
    case 0x6d:	pcpu->iyl = pcpu->iyl;		break;	/* ld iyl,iyl */
    case 0x6e:
      tmp16 = IYD;
      pcpu->l = z80_read(tmp16);
      pcpu->internal = tmp16 >> 8;		break;	/* ld l,(iy+d) */
    case 0x6f:	pcpu->iyl = pcpu->a;		break;	/* ld iyl,a */

    case 0x70:	z80_write(IYD, pcpu->b);	break;	/* ld (iy+d),b */
    case 0x71:	z80_write(IYD, pcpu->c);	break;	/* ld (iy+d),c */
    case 0x72:	z80_write(IYD, pcpu->d);	break;	/* ld (iy+d),d */
    case 0x73:	z80_write(IYD, pcpu->e);	break;	/* ld (iy+d),e */
    case 0x74:	z80_write(IYD, pcpu->h);	break;	/* ld (iy+d),h */
    case 0x75:	z80_write(IYD, pcpu->l);	break;	/* ld (iy+d),l */
    case 0x77:	z80_write(IYD, pcpu->a);	break;	/* ld (iy+d),a */

    case 0x7c:	pcpu->a = pcpu->iyh;		break;	/* ld a,iyh */
    case 0x7d:	pcpu->a = pcpu->iyl;		break;	/* ld a,iyl */
    case 0x7e:
      tmp16 = IYD;
      pcpu->a = z80_read(tmp16);
      pcpu->internal = tmp16 >> 8;		break;	/* ld a,(iy+d) */

    case 0x84:	ADD(pcpu->iyh);			break;	/* add a,iyh */
    case 0x85:	ADD(pcpu->iyl);			break;	/* add a,iyl */
    case 0x86:	ADD(z80_read(IYD));		break;	/* add a,(iy+d) */

    case 0x8c:	ADC(pcpu->iyh);			break;	/* adc a,iyh */
    case 0x8d:	ADC(pcpu->iyl);			break;	/* adc a,iyl */
    case 0x8e:	ADC(z80_read(IYD));		break;	/* adc a,(iy+d) */

    case 0x94:	SUB(pcpu->iyh);			break;	/* sub iyh */
    case 0x95:	SUB(pcpu->iyl);			break;	/* sub iyl */
    case 0x96:	SUB(z80_read(IYD));		break;	/* sub (iy+d) */

    case 0x9c:	SBC(pcpu->iyh);			break;	/* sbc a,iyh */
    case 0x9d:	SBC(pcpu->iyl);			break;	/* sbc a,iyl */
    case 0x9e:	SBC(z80_read(IYD));		break;	/* sbc (iy+d) */

    case 0xa4:	AND(pcpu->iyh);			break;	/* and iyh */
    case 0xa5:	AND(pcpu->iyl);			break;	/* and iyl */
    case 0xa6:	AND(z80_read(IYD));		break;	/* and (iy+d) */

    case 0xac:	XOR(pcpu->iyh);			break;	/* xor iyh */
    case 0xad:	XOR(pcpu->iyl);			break;	/* xor iyl */
    case 0xae:	XOR(z80_read(IYD));		break;	/* xor (iy+d) */

    case 0xb4:	OR(pcpu->iyh);			break;	/* or iyh */
    case 0xb5:	OR(pcpu->iyl);			break;	/* or iyl */
    case 0xb6:	OR(z80_read(IYD));		break;	/* or (iy+d) */

    case 0xbc:	CP(pcpu->iyh);			break;	/* cp iyh */
    case 0xbd:	CP(pcpu->iyl);			break;	/* cp iyl */
    case 0xbe:	CP(z80_read(IYD));		break;	/* cp (iy+d) */

    case 0xe1:	POP(iyh, iyl);			break;	/* pop iy */

    case 0xe3:						/* ex (sp),iy */
      tmp8 = z80_read(pcpu->sp);
      z80_write(pcpu->sp, pcpu->iyl);
      pcpu->iyl = tmp8;
      tmp8 = z80_read(pcpu->sp + 1);
      z80_write(pcpu->sp + 1, pcpu->iyh);
      pcpu->iyh = tmp8;
      break;

    case 0xe5:						/* push iy */
      PUSH(iyh, iyl);
      break;

    case 0xe9:						/* jp (iy) */
      pcpu->pc = IY;
      break;

    case 0xed:						/* ED prefix */
      exec_code(pcpu, 0xed);
      break;

    case 0xf9:						/* ld sp,iy */
      pcpu->sp = IY;
      break;

    case 0xcb:
      tmp16 = IYD;
      op = z80_read(pcpu->pc++);
      pcpu->cycles = tstates_ddcb[op];

      switch (op) {
      case 0x00:	IXY(RLC, pcpu->b);	break;	/* rlc (iy+d),b */
      case 0x01:	IXY(RLC, pcpu->c);	break;	/* rlc (iy+d),c */
      case 0x02:	IXY(RLC, pcpu->d);	break;	/* rlc (iy+d),d */
      case 0x03:	IXY(RLC, pcpu->e);	break;	/* rlc (iy+d),e */
      case 0x04:	IXY(RLC, pcpu->h);	break;	/* rlc (iy+d),h */
      case 0x05:	IXY(RLC, pcpu->l);	break;	/* rlc (iy+d),l */
      case 0x06:	IXY(RLC, tmp8);		break;	/* rlc (iy+d) */
      case 0x07:	IXY(RLC, pcpu->a);	break;	/* rlc (iy+d),a */

      case 0x08:	IXY(RRC, pcpu->b);	break;	/* rrc (iy+d),b */
      case 0x09:	IXY(RRC, pcpu->c);	break;	/* rrc (iy+d),c */
      case 0x0a:	IXY(RRC, pcpu->d);	break;	/* rrc (iy+d),d */
      case 0x0b:	IXY(RRC, pcpu->e);	break;	/* rrc (iy+d),e */
      case 0x0c:	IXY(RRC, pcpu->h);	break;	/* rrc (iy+d),h */
      case 0x0d:	IXY(RRC, pcpu->l);	break;	/* rrc (iy+d),l */
      case 0x0e:	IXY(RRC, tmp8);		break;	/* rrc (iy+d) */
      case 0x0f:	IXY(RRC, pcpu->a);	break;	/* rrc (iy+d),a */

      case 0x10:	IXY(RL, pcpu->b);	break;	/* rl (iy+d),b */
      case 0x11:	IXY(RL, pcpu->c);	break;	/* rl (iy+d),c */
      case 0x12:	IXY(RL, pcpu->d);	break;	/* rl (iy+d),d */
      case 0x13:	IXY(RL, pcpu->e);	break;	/* rl (iy+d),e */
      case 0x14:	IXY(RL, pcpu->h);	break;	/* rl (iy+d),h */
      case 0x15:	IXY(RL, pcpu->l);	break;	/* rl (iy+d),l */
      case 0x16:	IXY(RL, tmp8);		break;	/* rl (iy+d) */
      case 0x17:	IXY(RL, pcpu->a);	break;	/* rl (iy+d),a */

      case 0x18:	IXY(RR, pcpu->b);	break;	/* rr (iy+d),b */
      case 0x19:	IXY(RR, pcpu->c);	break;	/* rr (iy+d),c */
      case 0x1a:	IXY(RR, pcpu->d);	break;	/* rr (iy+d),d */
      case 0x1b:	IXY(RR, pcpu->e);	break;	/* rr (iy+d),e */
      case 0x1c:	IXY(RR, pcpu->h);	break;	/* rr (iy+d),h */
      case 0x1d:	IXY(RR, pcpu->l);	break;	/* rr (iy+d),l */
      case 0x1e:	IXY(RR, tmp8);		break;	/* rr (iy+d) */
      case 0x1f:	IXY(RR, pcpu->a);	break;	/* rr (iy+d),a */

      case 0x20:	IXY(SLA, pcpu->b);	break;	/* sla (iy+d),b */
      case 0x21:	IXY(SLA, pcpu->c);	break;	/* sla (iy+d),c */
      case 0x22:	IXY(SLA, pcpu->d);	break;	/* sla (iy+d),d */
      case 0x23:	IXY(SLA, pcpu->e);	break;	/* sla (iy+d),e */
      case 0x24:	IXY(SLA, pcpu->h);	break;	/* sla (iy+d),h */
      case 0x25:	IXY(SLA, pcpu->l);	break;	/* sla (iy+d),l */
      case 0x26:	IXY(SLA, tmp8);		break;	/* sla (iy+d) */
      case 0x27:	IXY(SLA, pcpu->a);	break;	/* sla (iy+d),a */

      case 0x28:	IXY(SRA, pcpu->b);	break;	/* sra (iy+d),b */
      case 0x29:	IXY(SRA, pcpu->c);	break;	/* sra (iy+d),c */
      case 0x2a:	IXY(SRA, pcpu->d);	break;	/* sra (iy+d),d */
      case 0x2b:	IXY(SRA, pcpu->e);	break;	/* sra (iy+d),e */
      case 0x2c:	IXY(SRA, pcpu->h);	break;	/* sra (iy+d),h */
      case 0x2d:	IXY(SRA, pcpu->l);	break;	/* sra (iy+d),l */
      case 0x2e:	IXY(SRA, tmp8);		break;	/* sra (iy+d) */
      case 0x2f:	IXY(SRA, pcpu->a);	break;	/* sra (iy+d),a */

      case 0x30:	IXY(SLL, pcpu->b);	break;	/* sll (iy+d),b */
      case 0x31:	IXY(SLL, pcpu->c);	break;	/* sll (iy+d),c */
      case 0x32:	IXY(SLL, pcpu->d);	break;	/* sll (iy+d),d */
      case 0x33:	IXY(SLL, pcpu->e);	break;	/* sll (iy+d),e */
      case 0x34:	IXY(SLL, pcpu->h);	break;	/* sll (iy+d),h */
      case 0x35:	IXY(SLL, pcpu->l);	break;	/* sll (iy+d),l */
      case 0x36:	IXY(SLL, tmp8);		break;	/* sll (iy+d) */
      case 0x37:	IXY(SLL, pcpu->a);	break;	/* sll (iy+d),a */

      case 0x38:	IXY(SRL, pcpu->b);	break;	/* srl (iy+d),b */
      case 0x39:	IXY(SRL, pcpu->c);	break;	/* srl (iy+d),c */
      case 0x3a:	IXY(SRL, pcpu->d);	break;	/* srl (iy+d),d */
      case 0x3b:	IXY(SRL, pcpu->e);	break;	/* srl (iy+d),e */
      case 0x3c:	IXY(SRL, pcpu->h);	break;	/* srl (iy+d),h */
      case 0x3d:	IXY(SRL, pcpu->l);	break;	/* srl (iy+d),l */
      case 0x3e:	IXY(SRL, tmp8);		break;	/* srl (iy+d) */
      case 0x3f:	IXY(SRL, pcpu->a);	break;	/* srl (iy+d),a */

      case 0x40:	case 0x41:	case 0x42:	case 0x43:
      case 0x44:	case 0x45:	case 0x46:	case 0x47:
      case 0x48:	case 0x49:	case 0x4a:	case 0x4b:
      case 0x4c:	case 0x4d:	case 0x4e:	case 0x4f:
      case 0x50:	case 0x51:	case 0x52:	case 0x53:
      case 0x54:	case 0x55:	case 0x56:	case 0x57:
      case 0x58:	case 0x59:	case 0x5a:	case 0x5b:
      case 0x5c:	case 0x5d:	case 0x5e:	case 0x5f:
      case 0x60:	case 0x61:	case 0x62:	case 0x63:
      case 0x64:	case 0x65:	case 0x66:	case 0x67:
      case 0x68:	case 0x69:	case 0x6a:	case 0x6b:
      case 0x6c:	case 0x6d:	case 0x6e:	case 0x6f:
      case 0x70:	case 0x71:	case 0x72:	case 0x73:
      case 0x74:	case 0x75:	case 0x76:	case 0x77:
      case 0x78:	case 0x79:	case 0x7a:	case 0x7b:
      case 0x7c:	case 0x7d:	case 0x7e:	case 0x7f:
	BITIXY((op >> 3) & 0x07, z80_read(tmp16));	/* bit n,(iy+d) */
	break;

      case 0x80:	IXY2(RES, 0, pcpu->b);	break;	/* res 0,(iy+d),b */
      case 0x81:	IXY2(RES, 0, pcpu->c);	break;	/* res 0,(iy+d),c */
      case 0x82:	IXY2(RES, 0, pcpu->d);	break;	/* res 0,(iy+d),d */
      case 0x83:	IXY2(RES, 0, pcpu->e);	break;	/* res 0,(iy+d),e */
      case 0x84:	IXY2(RES, 0, pcpu->h);	break;	/* res 0,(iy+d),h */
      case 0x85:	IXY2(RES, 0, pcpu->l);	break;	/* res 0,(iy+d),l */
      case 0x86:	IXY2(RES, 0, tmp8);	break;	/* res 0,(iy+d) */
      case 0x87:	IXY2(RES, 0, pcpu->a);	break;	/* res 0,(iy+d),a */
      case 0x88:	IXY2(RES, 1, pcpu->b);	break;	/* res 1,(iy+d),b */
      case 0x89:	IXY2(RES, 1, pcpu->c);	break;	/* res 1,(iy+d),c */
      case 0x8a:	IXY2(RES, 1, pcpu->d);	break;	/* res 1,(iy+d),d */
      case 0x8b:	IXY2(RES, 1, pcpu->e);	break;	/* res 1,(iy+d),e */
      case 0x8c:	IXY2(RES, 1, pcpu->h);	break;	/* res 1,(iy+d),h */
      case 0x8d:	IXY2(RES, 1, pcpu->l);	break;	/* res 1,(iy+d),l */
      case 0x8e:	IXY2(RES, 1, tmp8);	break;	/* res 1,(iy+d) */
      case 0x8f:	IXY2(RES, 1, pcpu->a);	break;	/* res 1,(iy+d),a */
      case 0x90:	IXY2(RES, 2, pcpu->b);	break;	/* res 2,(iy+d),b */
      case 0x91:	IXY2(RES, 2, pcpu->c);	break;	/* res 2,(iy+d),c */
      case 0x92:	IXY2(RES, 2, pcpu->d);	break;	/* res 2,(iy+d),d */
      case 0x93:	IXY2(RES, 2, pcpu->e);	break;	/* res 2,(iy+d),e */
      case 0x94:	IXY2(RES, 2, pcpu->h);	break;	/* res 2,(iy+d),h */
      case 0x95:	IXY2(RES, 2, pcpu->l);	break;	/* res 2,(iy+d),l */
      case 0x96:	IXY2(RES, 2, tmp8);	break;	/* res 2,(iy+d) */
      case 0x97:	IXY2(RES, 2, pcpu->a);	break;	/* res 2,(iy+d),a */
      case 0x98:	IXY2(RES, 3, pcpu->b);	break;	/* res 3,(iy+d),b */
      case 0x99:	IXY2(RES, 3, pcpu->c);	break;	/* res 3,(iy+d),c */
      case 0x9a:	IXY2(RES, 3, pcpu->d);	break;	/* res 3,(iy+d),d */
      case 0x9b:	IXY2(RES, 3, pcpu->e);	break;	/* res 3,(iy+d),e */
      case 0x9c:	IXY2(RES, 3, pcpu->h);	break;	/* res 3,(iy+d),h */
      case 0x9d:	IXY2(RES, 3, pcpu->l);	break;	/* res 3,(iy+d),l */
      case 0x9e:	IXY2(RES, 3, tmp8);	break;	/* res 3,(iy+d) */
      case 0x9f:	IXY2(RES, 3, pcpu->a);	break;	/* res 3,(iy+d),a */
      case 0xa0:	IXY2(RES, 4, pcpu->b);	break;	/* res 4,(iy+d),b */
      case 0xa1:	IXY2(RES, 4, pcpu->c);	break;	/* res 4,(iy+d),c */
      case 0xa2:	IXY2(RES, 4, pcpu->d);	break;	/* res 4,(iy+d),d */
      case 0xa3:	IXY2(RES, 4, pcpu->e);	break;	/* res 4,(iy+d),e */
      case 0xa4:	IXY2(RES, 4, pcpu->h);	break;	/* res 4,(iy+d),h */
      case 0xa5:	IXY2(RES, 4, pcpu->l);	break;	/* res 4,(iy+d),l */
      case 0xa6:	IXY2(RES, 4, tmp8);	break;	/* res 4,(iy+d) */
      case 0xa7:	IXY2(RES, 4, pcpu->a);	break;	/* res 4,(iy+d),a */
      case 0xa8:	IXY2(RES, 5, pcpu->b);	break;	/* res 5,(iy+d),b */
      case 0xa9:	IXY2(RES, 5, pcpu->c);	break;	/* res 5,(iy+d),c */
      case 0xaa:	IXY2(RES, 5, pcpu->d);	break;	/* res 5,(iy+d),d */
      case 0xab:	IXY2(RES, 5, pcpu->e);	break;	/* res 5,(iy+d),e */
      case 0xac:	IXY2(RES, 5, pcpu->h);	break;	/* res 5,(iy+d),h */
      case 0xad:	IXY2(RES, 5, pcpu->l);	break;	/* res 5,(iy+d),l */
      case 0xae:	IXY2(RES, 5, tmp8);	break;	/* res 5,(iy+d) */
      case 0xaf:	IXY2(RES, 5, pcpu->a);	break;	/* res 5,(iy+d),a */
      case 0xb0:	IXY2(RES, 6, pcpu->b);	break;	/* res 6,(iy+d),b */
      case 0xb1:	IXY2(RES, 6, pcpu->c);	break;	/* res 6,(iy+d),c */
      case 0xb2:	IXY2(RES, 6, pcpu->d);	break;	/* res 6,(iy+d),d */
      case 0xb3:	IXY2(RES, 6, pcpu->e);	break;	/* res 6,(iy+d),e */
      case 0xb4:	IXY2(RES, 6, pcpu->h);	break;	/* res 6,(iy+d),h */
      case 0xb5:	IXY2(RES, 6, pcpu->l);	break;	/* res 6,(iy+d),l */
      case 0xb6:	IXY2(RES, 6, tmp8);	break;	/* res 6,(iy+d) */
      case 0xb7:	IXY2(RES, 6, pcpu->a);	break;	/* res 6,(iy+d),a */
      case 0xb8:	IXY2(RES, 7, pcpu->b);	break;	/* res 7,(iy+d),b */
      case 0xb9:	IXY2(RES, 7, pcpu->c);	break;	/* res 7,(iy+d),c */
      case 0xba:	IXY2(RES, 7, pcpu->d);	break;	/* res 7,(iy+d),d */
      case 0xbb:	IXY2(RES, 7, pcpu->e);	break;	/* res 7,(iy+d),e */
      case 0xbc:	IXY2(RES, 7, pcpu->h);	break;	/* res 7,(iy+d),h */
      case 0xbd:	IXY2(RES, 7, pcpu->l);	break;	/* res 7,(iy+d),l */
      case 0xbe:	IXY2(RES, 7, tmp8);	break;	/* res 7,(iy+d) */
      case 0xbf:	IXY2(RES, 7, pcpu->a);	break;	/* res 7,(iy+d),a */
      case 0xc0:	IXY2(SET, 0, pcpu->b);	break;	/* res 0,(iy+d),b */
      case 0xc1:	IXY2(SET, 0, pcpu->c);	break;	/* res 0,(iy+d),c */
      case 0xc2:	IXY2(SET, 0, pcpu->d);	break;	/* res 0,(iy+d),d */
      case 0xc3:	IXY2(SET, 0, pcpu->e);	break;	/* res 0,(iy+d),e */
      case 0xc4:	IXY2(SET, 0, pcpu->h);	break;	/* res 0,(iy+d),h */
      case 0xc5:	IXY2(SET, 0, pcpu->l);	break;	/* res 0,(iy+d),l */
      case 0xc6:	IXY2(SET, 0, tmp8);	break;	/* res 0,(iy+d) */
      case 0xc7:	IXY2(SET, 0, pcpu->a);	break;	/* res 0,(iy+d),a */
      case 0xc8:	IXY2(SET, 1, pcpu->b);	break;	/* res 1,(iy+d),b */
      case 0xc9:	IXY2(SET, 1, pcpu->c);	break;	/* res 1,(iy+d),c */
      case 0xca:	IXY2(SET, 1, pcpu->d);	break;	/* res 1,(iy+d),d */
      case 0xcb:	IXY2(SET, 1, pcpu->e);	break;	/* res 1,(iy+d),e */
      case 0xcc:	IXY2(SET, 1, pcpu->h);	break;	/* res 1,(iy+d),h */
      case 0xcd:	IXY2(SET, 1, pcpu->l);	break;	/* res 1,(iy+d),l */
      case 0xce:	IXY2(SET, 1, tmp8);	break;	/* res 1,(iy+d) */
      case 0xcf:	IXY2(SET, 1, pcpu->a);	break;	/* res 1,(iy+d),a */
      case 0xd0:	IXY2(SET, 2, pcpu->b);	break;	/* res 2,(iy+d),b */
      case 0xd1:	IXY2(SET, 2, pcpu->c);	break;	/* res 2,(iy+d),c */
      case 0xd2:	IXY2(SET, 2, pcpu->d);	break;	/* res 2,(iy+d),d */
      case 0xd3:	IXY2(SET, 2, pcpu->e);	break;	/* res 2,(iy+d),e */
      case 0xd4:	IXY2(SET, 2, pcpu->h);	break;	/* res 2,(iy+d),h */
      case 0xd5:	IXY2(SET, 2, pcpu->l);	break;	/* res 2,(iy+d),l */
      case 0xd6:	IXY2(SET, 2, tmp8);	break;	/* res 2,(iy+d) */
      case 0xd7:	IXY2(SET, 2, pcpu->a);	break;	/* res 2,(iy+d),a */
      case 0xd8:	IXY2(SET, 3, pcpu->b);	break;	/* res 3,(iy+d),b */
      case 0xd9:	IXY2(SET, 3, pcpu->c);	break;	/* res 3,(iy+d),c */
      case 0xda:	IXY2(SET, 3, pcpu->d);	break;	/* res 3,(iy+d),d */
      case 0xdb:	IXY2(SET, 3, pcpu->e);	break;	/* res 3,(iy+d),e */
      case 0xdc:	IXY2(SET, 3, pcpu->h);	break;	/* res 3,(iy+d),h */
      case 0xdd:	IXY2(SET, 3, pcpu->l);	break;	/* res 3,(iy+d),l */
      case 0xde:	IXY2(SET, 3, tmp8);	break;	/* res 3,(iy+d) */
      case 0xdf:	IXY2(SET, 3, pcpu->a);	break;	/* res 3,(iy+d),a */
      case 0xe0:	IXY2(SET, 4, pcpu->b);	break;	/* res 4,(iy+d),b */
      case 0xe1:	IXY2(SET, 4, pcpu->c);	break;	/* res 4,(iy+d),c */
      case 0xe2:	IXY2(SET, 4, pcpu->d);	break;	/* res 4,(iy+d),d */
      case 0xe3:	IXY2(SET, 4, pcpu->e);	break;	/* res 4,(iy+d),e */
      case 0xe4:	IXY2(SET, 4, pcpu->h);	break;	/* res 4,(iy+d),h */
      case 0xe5:	IXY2(SET, 4, pcpu->l);	break;	/* res 4,(iy+d),l */
      case 0xe6:	IXY2(SET, 4, tmp8);	break;	/* res 4,(iy+d) */
      case 0xe7:	IXY2(SET, 4, pcpu->a);	break;	/* res 4,(iy+d),a */
      case 0xe8:	IXY2(SET, 5, pcpu->b);	break;	/* res 5,(iy+d),b */
      case 0xe9:	IXY2(SET, 5, pcpu->c);	break;	/* res 5,(iy+d),c */
      case 0xea:	IXY2(SET, 5, pcpu->d);	break;	/* res 5,(iy+d),d */
      case 0xeb:	IXY2(SET, 5, pcpu->e);	break;	/* res 5,(iy+d),e */
      case 0xec:	IXY2(SET, 5, pcpu->h);	break;	/* res 5,(iy+d),h */
      case 0xed:	IXY2(SET, 5, pcpu->l);	break;	/* res 5,(iy+d),l */
      case 0xee:	IXY2(SET, 5, tmp8);	break;	/* res 5,(iy+d) */
      case 0xef:	IXY2(SET, 5, pcpu->a);	break;	/* res 5,(iy+d),a */
      case 0xf0:	IXY2(SET, 6, pcpu->b);	break;	/* res 6,(iy+d),b */
      case 0xf1:	IXY2(SET, 6, pcpu->c);	break;	/* res 6,(iy+d),c */
      case 0xf2:	IXY2(SET, 6, pcpu->d);	break;	/* res 6,(iy+d),d */
      case 0xf3:	IXY2(SET, 6, pcpu->e);	break;	/* res 6,(iy+d),e */
      case 0xf4:	IXY2(SET, 6, pcpu->h);	break;	/* res 6,(iy+d),h */
      case 0xf5:	IXY2(SET, 6, pcpu->l);	break;	/* res 6,(iy+d),l */
      case 0xf6:	IXY2(SET, 6, tmp8);	break;	/* res 6,(iy+d) */
      case 0xf7:	IXY2(SET, 6, pcpu->a);	break;	/* res 6,(iy+d),a */
      case 0xf8:	IXY2(SET, 7, pcpu->b);	break;	/* res 7,(iy+d),b */
      case 0xf9:	IXY2(SET, 7, pcpu->c);	break;	/* res 7,(iy+d),c */
      case 0xfa:	IXY2(SET, 7, pcpu->d);	break;	/* res 7,(iy+d),d */
      case 0xfb:	IXY2(SET, 7, pcpu->e);	break;	/* res 7,(iy+d),e */
      case 0xfc:	IXY2(SET, 7, pcpu->h);	break;	/* res 7,(iy+d),h */
      case 0xfd:	IXY2(SET, 7, pcpu->l);	break;	/* res 7,(iy+d),l */
      case 0xfe:	IXY2(SET, 7, tmp8);	break;	/* res 7,(iy+d) */
      case 0xff:	IXY2(SET, 7, pcpu->a);	break;	/* res 7,(iy+d),a */
      }
      break;						/* FDCB prefix */

    default:
      exec_code(pcpu, op);
      break;
    }
    break;						/* FD prefix */
  }
}

/*
 * search Z80 machine code
 */
int search_code(const char **mnem, char ixiy, char *input, byte *data, word address)
{
  int i, j;
  int value1, value2, n;
  int narg;
  char format[20];
  char *pos;

  if (strlen(input) == 0) {
    return 0;
  }

  for (i = 0; i < 0x100; i++) {
    strcpy(format, mnem[i]);
    for (j = 0; j < 2; j++) {
      if (pos = strchr(format, '%')) {
	*pos = ixiy;
	*(pos + 1) = toupper((int)*(pos + 1));	/* h,l */
      }
    }
    narg = 0;
    if ((pos = strchr(format, '#'))
	|| (pos = strchr(format, '^'))
	|| (pos = strchr(format, '*'))
	|| (pos = strchr(format, '@'))) {
      memmove(pos + 3, pos + 2, strlen(pos) - 1);
      memcpy(pos, "%xH", 3);
      narg = 1;

      if (pos = strchr(format, '*')) {
	memmove(pos + 3, pos + 2, strlen(pos) - 1);
	memcpy(pos, "%xH", 3);
	narg++;
      }
    }

    strcat(format, "%n");
    n = 0;
    switch (narg) {
    case 0:
      sscanf(input, format, &n);
      break;
    case 1:
      sscanf(input, format, &value1, &n);
      break;
    case 2:
      sscanf(input, format, &value1, &value2, &n);
      break;
    }
    if (n != strlen(input)) {
      continue;
    }

    switch (narg) {
    case 0:
      data[0] = i;
      return 1;
    case 1:
      data[0] = i;
      if (strchr(mnem[i], '#')) {
	value1 = upperhex(value1, 0xffff);
	data[1] = value1 & 0xff;
	data[2] = value1 >> 8;
	return 3;
      } else if (strchr(mnem[i], '*') || strchr(mnem[i], '^')) {
	data[1] = upperhex(value1, 0xff);
	return 2;
      } else if (strchr(mnem[i], '@')) {
	data[1] = (upperhex(value1, 0xffff) - address - 2) & 0xff;
	return 2;
      }
    case 2:
      data[0] = i;
      data[1] = upperhex(value1, 0xff);
      data[2] = upperhex(value2, 0xff);
      return 3;
    }
  }

  return 0;
}

/*
 * get the upper hex digits
 */
int upperhex(int value, int mask)
{
  if (value < 0) {
    value = -value;
    while (value > mask) {
      value >>= 4;
    }
    value = -value;
  }
  while (value > mask) {
    value >>= 4;
  }

  return value;
}
